@@ -14,25 +14,26 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #ifndef __AOX_H__
 #define __AOX_H__
 
-#include <libgphoto2_port/gphoto2-port.h>
+#include <gphoto2/gphoto2-port.h>
 
 typedef unsigned char Info;
 
 typedef enum {
-	MODEL_MINI
+	AOX_MODEL_MINI,
+	AOX_MODEL_DMAX
 } Model;
 
 int aox_init              (GPPort *port, Model *model, Info *info);
 int aox_get_num_lo_pics   (Info *info);
 int aox_get_num_hi_pics   (Info *info);
-int aox_read_data         (GPPort *port, char *data, int size);
+
 int aox_get_picture_size  (GPPort *port, int lo, int hi, int n, int k);
 int aox_read_picture_data (GPPort *port, char *data, int size, int n);
 
