@@ -14,10 +14,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
+#define _BSD_SOURCE
+
 #include <config.h>
 
 #include <stdlib.h>
@@ -132,18 +134,18 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	int num_lo_pics = aox_get_num_lo_pics (camera->pl->info);
 	int num_hi_pics = aox_get_num_hi_pics (camera->pl->info);
 	int n = num_hi_pics + num_lo_pics;
-	char name[n];
+	char name[20];
 	int i;	
 	/* Low-resolution pictures are always downloaded first. We do not know 
 	 * yet how to process them, so they will remain in RAW format. */
 	
 	for (i=0; i< num_lo_pics; i++){
-		sprintf( name, "aox_pic%03i.raw", i+1 );
+		snprintf( name, sizeof(name), "aox_pic%03i.raw", i+1 );
 		gp_list_append(list, name, NULL);	
 	}
 
 	for (i = num_lo_pics; i < n; i++){
-		sprintf( name, "aox_pic%03i.ppm", i+1 );		
+		snprintf( name, sizeof(name), "aox_pic%03i.ppm", i+1 );		
 		gp_list_append(list, name, NULL);	
 	}
     	return GP_OK;
@@ -231,8 +233,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 				p_data[4*i + 1] = p_data[4*i+2];
 				p_data[4*i+2] = temp;
 			}
-			GP_DEBUG("size of data = %i\n", sizeof(data));
-			GP_DEBUG("size of p_data = %i\n", sizeof(p_data));
 			/* And now create a ppm file, with our own header */
 			header_len = snprintf(header, 127, 
 				"P6\n" 
@@ -344,6 +344,7 @@ camera_init(Camera *camera, GPContext *context)
 	switch(abilities.usb_product) {
 	case 0x2130:
 		camera->pl->model = AOX_MODEL_DMAX;
+		break;
 	default:
 		camera->pl->model = AOX_MODEL_MINI;
 	}
