@@ -338,11 +338,7 @@ canon_serial_recv_frame (Camera *camera, int *len)
 		*p++ = c;
 	}
 
-	/* If you don't want to see the data dumped, change the frontend to
-	 * set a lower debug level
-	 */
-	gp_log (GP_LOG_DATA, "canon", "RECV (without CANON_FBEG and CANON_FEND bytes)");
-	gp_log_data ("canon", (char *)buffer, p - buffer);
+	GP_LOG_DATA ((char *)buffer, p - buffer, "RECV (without CANON_FBEG and CANON_FEND bytes)");
 
 	if (len)
 		*len = p - buffer;
@@ -371,7 +367,7 @@ canon_serial_send_packet (Camera *camera, unsigned char type, unsigned char seq,
 			  unsigned char *pkt, int len)
 {
 	unsigned char *hdr = pkt - PKT_HDR_LEN;
-	unsigned short crc;
+	int crc;
 
 	hdr[PKT_TYPE] = type;
 	hdr[PKT_SEQ] = seq;
@@ -392,6 +388,8 @@ canon_serial_send_packet (Camera *camera, unsigned char type, unsigned char seq,
 	if (type == PKT_EOT || type == PKT_ACK || type == PKT_NACK)
 		len = 2;	/* @@@ hack */
 	crc = canon_psa50_gen_crc (hdr, len + PKT_HDR_LEN);
+	if (crc == -1)
+		return GP_ERROR;
 	pkt[len] = crc & 0xff;
 	pkt[len + 1] = crc >> 8;
 
@@ -724,10 +722,8 @@ canon_serial_recv_msg (Camera *camera, unsigned char mtype, unsigned char dir, u
 			if (msg_pos + len > msg_size || !msg) {
 				msg_size *= 2;
 				msg = realloc (msg, msg_size);
-				if (!msg) {
-					perror ("realloc");
-					exit (1);
-				}
+				if (!msg)
+					return NULL;
 			}
 			memcpy (msg + msg_pos, frag, len);
 			msg_pos += len;
@@ -968,7 +964,6 @@ canon_serial_put_file (Camera *camera, CameraFile *file, const char *name, const
 		       GPContext *context)
 {
 	unsigned char *msg;
-	char filename[64];
 	char buf[4096];
 	int offset = 0;
 	char offset2[4];
@@ -976,17 +971,12 @@ canon_serial_put_file (Camera *camera, CameraFile *file, const char *name, const
 	char block_len2[4];
 	unsigned int sent = 0;
 	int i, j = 0;
-	unsigned int len, hdr_len;
+	unsigned int len;
 	unsigned long int size;
 	const char *data;
 	unsigned int id;
 
 	camera->pl->uploading = 1;
-	for (i = 0; name[i]; i++)
-		filename[i] = toupper (name[i]);
-	filename[i] = '\0';
-
-	hdr_len = HDR_FIXED_LEN + strlen (name) + strlen (destpath);
 
 	gp_file_get_data_and_size (file, &data, &size);
 
@@ -1145,11 +1135,9 @@ canon_serial_get_dirents (Camera *camera, unsigned char **dirent_data,
 		return GP_ERROR;
 	}
 
-	/* don't use GP_DEBUG since we log this with GP_LOG_DATA */
-	gp_log (GP_LOG_DATA, "canon",
-		"canon_serial_get_dirents: "
-		"dirent packet received from canon_serial_dialogue:");
-	gp_log_data ("canon", (char *)p, *dirents_length);
+	GP_LOG_DATA ((char *)p, *dirents_length,
+				 "canon_serial_get_dirents: "
+				 "dirent packet received from canon_serial_dialogue:");
 
 	/* the first five bytes is only for the RS232 implementation
 	 * of this command, we do not need to copy them so therefore
@@ -1186,11 +1174,9 @@ canon_serial_get_dirents (Camera *camera, unsigned char **dirent_data,
 			return GP_ERROR;
 		}
 
-		/* don't use GP_DEBUG since we log this with GP_LOG_DATA */
-		gp_log (GP_LOG_DATA, "canon",
-			"canon_serial_get_dirents: "
-			"dirent packet received from canon_serial_recv_msg:");
-		gp_log_data ("canon", (char *)p, *dirents_length);
+		GP_LOG_DATA ((char *)p, *dirents_length,
+					 "canon_serial_get_dirents: "
+					 "dirent packet received from canon_serial_recv_msg:");
 
 		/* the first five bytes is only for the RS232 implementation,
 		 * don't count them when checking dirent size
