@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "casio-qv-commands.h"
 #include "camtojpeg.h"
@@ -132,17 +133,17 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
 	switch (type) {
 	case GP_FILE_TYPE_RAW:
-		CHECK_RESULT (QVgetCAMpic (camera, &data, &size, attr&2));
+		CHECK_RESULT (QVgetCAMpic (camera, &data, (long unsigned *)&size, attr&2));
 		CHECK_RESULT (gp_file_set_mime_type(file, GP_MIME_RAW));
 		break;
 	case GP_FILE_TYPE_PREVIEW:
-		CHECK_RESULT (QVgetYCCpic (camera, &cam, &camSize));
+		CHECK_RESULT (QVgetYCCpic (camera, &cam, (long unsigned *)&camSize));
 		CHECK_RESULT (QVycctoppm(cam, camSize, THUMBNAIL_WIDTH, THUMBNAIL_HEIGHT, 2, &data, &size));
 		free(cam);
 		CHECK_RESULT (gp_file_set_mime_type (file, GP_MIME_PPM));
 		break;
 	case GP_FILE_TYPE_NORMAL:
-		CHECK_RESULT (QVgetCAMpic (camera, &cam, &camSize, attr&2));
+		CHECK_RESULT (QVgetCAMpic (camera, &cam, (long unsigned *)&camSize, attr&2));
 		CHECK_RESULT ((attr&2 ? QVfinecamtojpeg : QVcamtojpeg)(cam, camSize, &data, &size));
 		free(cam);
 		CHECK_RESULT (gp_file_set_mime_type (file, GP_MIME_JPEG));
