@@ -1,3 +1,23 @@
+/* dc120.c
+ *
+ * Copyright (C) Scott Fritzinger
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 #define _BSD_SOURCE
 #define _POSIX_C_SOURCE 199309L
 #include "config.h"
@@ -6,6 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <unistd.h>
 #include <gphoto2/gphoto2.h>
 
 #include "dc120.h"
@@ -74,7 +95,7 @@ dc120_packet_write (Camera *camera, char *packet, int size, int read_response) {
 write_again:
 	/* If retry, give camera some recup time */
 	if (x > 0)
-		GP_SYSTEM_SLEEP(SLEEP_TIMEOUT);
+		usleep(SLEEP_TIMEOUT * 1000);
 
 	/* Return error if too many retries */
 	if (x++ > RETRIES) 
@@ -86,7 +107,7 @@ write_again:
 
 	/* Read in the response from the camera if requested */
 	if (read_response) {
-		if (gp_port_read(camera->port, in, 1) < GP_OK)
+		if (gp_port_read(camera->port, (char *)in, 1) < GP_OK)
 			/* On error, write again */
 			goto write_again;
 
@@ -263,7 +284,7 @@ int dc120_set_speed (Camera *camera, int speed)
 	gp_port_set_settings (camera->port, settings);
 
 
-	GP_SYSTEM_SLEEP(300);
+	usleep(300 * 1000);
 
 	/* Speed change went OK. */
 	error = GP_OK;
@@ -288,7 +309,7 @@ int dc120_get_status (Camera *camera, Kodak_dc120_status *status, GPContext *con
         if( retval == (GP_OK) && status != NULL )
         {
 	    const char *data;
-	    long int  lsize;
+	    long unsigned int  lsize;
 
 	    gp_file_get_data_and_size( file, &data, &lsize );
 	    if( lsize<122 ) {
@@ -361,7 +382,7 @@ int dc120_get_albums (Camera *camera, int from_card, CameraList *list, GPContext
 	char *f;
 	char *p = dc120_packet_new(0x44);
 	const char *file_data;
-	long int file_size;
+	long unsigned int file_size;
 
 	if (from_card)
 		p[1] = 0x01;
@@ -396,7 +417,7 @@ int dc120_get_filenames (Camera *camera, int from_card, int album_number, Camera
 	char *p;
 	char buf[16];
 	const char *file_data;
-	long int file_size;
+	long unsigned int file_size;
 
 	/* --- now read the files --- */
 
@@ -443,20 +464,22 @@ static int dc120_get_file_preview (Camera *camera, CameraFile *file, int file_nu
 	int x;
 	char buf[16];
 	const char *f_data;
-	long int f_size;
+	long unsigned int f_size;
 
 	*size = 15680;
 
 	/* Create a file for KDC data */
 	gp_file_new(&f);
 	if (dc120_packet_read_data(camera, f, cmd_packet, size, 1024, context)==GP_ERROR) {
-		gp_file_free(file);
+		gp_file_free(f);
 		return (GP_ERROR);
 	}
 	/* Convert to PPM file for now */
 	gp_file_append(file, "P3\n80 60\n255\n", 13);
+
+	gp_file_get_data_and_size (f, &f_data, &f_size);
+
 	for (x=0; x<14400; x+=3) {
-		gp_file_get_data_and_size (f, &f_data, &f_size);
 		sprintf(buf, "%i %i %i\n",
 			(unsigned char)f_data[x+1280],
 			(unsigned char)f_data[x+1281],
@@ -464,7 +487,7 @@ static int dc120_get_file_preview (Camera *camera, CameraFile *file, int file_nu
 		gp_file_append(file, buf, strlen(buf));
 	}
 
-	GP_SYSTEM_SLEEP(1000);
+	sleep(1); /* FIXME: why? */
 	return (GP_OK);
 }
 
@@ -473,7 +496,7 @@ static int dc120_get_file (Camera *camera, CameraFile *file, int file_number, ch
         CameraFile *size_file; /* file used to determine the filesize */
   	char *p;
 	const char *file_data;
-	long int file_size;
+	long unsigned int file_size;
 	int offset;
 
 	/* --- first read the file size --- */
