@@ -1,3 +1,24 @@
+/* dc210.c
+ *
+ * Copyright (C) 2002 Michel Koltan <koltan@gmx.de>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
+#define _BSD_SOURCE
 #include "config.h"
 
 #include <stdlib.h>
@@ -5,8 +26,8 @@
 #include <string.h>
 #include <time.h>
 
-#include <gphoto2.h>
-#include <gphoto2-port.h>
+#include <gphoto2/gphoto2.h>
+#include <gphoto2/gphoto2-port.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -68,7 +89,6 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
     Camera *camera = data;
     
     return dc210_get_filenames(camera, list, context);
-    
 }
 
 static int get_file_func (CameraFilesystem *fs, const char *folder,
@@ -108,21 +128,18 @@ static int get_info_func (CameraFilesystem *fs, const char *folder, const char *
 	if (dc210_get_picture_info_by_name(camera, &picinfo, file) == GP_ERROR)
 		return GP_ERROR;
 
+	info->preview.fields  = 0;
 	info->preview.fields |= GP_FILE_INFO_TYPE;
-	info->preview.fields |= GP_FILE_INFO_NAME;
 	info->preview.fields |= GP_FILE_INFO_SIZE;
 	info->preview.fields |= GP_FILE_INFO_WIDTH;
 	info->preview.fields |= GP_FILE_INFO_HEIGHT;
-
 	strcpy(info->preview.type, GP_MIME_PPM);
 	info->preview.width = 96;
 	info->preview.height = 72;
 	info->preview.size = picinfo.preview_size;
-	strncpy(info->file.name, picinfo.image_name, 9);
-	strncpy(info->file.name + 9, "PPM\0", 4);
 
+	info->file.fields  = 0;
 	info->file.fields |= GP_FILE_INFO_TYPE;
-	info->file.fields |= GP_FILE_INFO_NAME;
 	info->file.fields |= GP_FILE_INFO_SIZE;
 	info->file.fields |= GP_FILE_INFO_WIDTH;
 	info->file.fields |= GP_FILE_INFO_HEIGHT;
@@ -145,14 +162,9 @@ static int get_info_func (CameraFilesystem *fs, const char *folder, const char *
 		info->file.height = 864;
 		break;
 	};
-	strncpy(info->file.name, picinfo.image_name, 13);
 	info->file.mtime = picinfo.picture_time;
-
-	info->audio.fields |= GP_FILE_INFO_NONE;
-
 	return GP_OK;
-
-};
+}
 
 
 static int
@@ -447,8 +459,6 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 }
 
 static int camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path, GPContext *context) {
-
-
 	if (type && type != GP_CAPTURE_IMAGE){
 		DC210_DEBUG("Unsupported action 0x%.2X\n", type);
 		return (GP_ERROR_NOT_SUPPORTED);
@@ -457,15 +467,10 @@ static int camera_capture (Camera *camera, CameraCaptureType type, CameraFilePat
 	if (dc210_capture(camera, path, context) == GP_ERROR) 
 		return GP_ERROR;
 
-	if (gp_filesystem_append (camera->fs, path->folder, path->name, context) == GP_ERROR)
-		return GP_ERROR;;
-
-        return (GP_OK);
-
+	return gp_filesystem_append (camera->fs, path->folder, path->name, context);
 }
 
 static int camera_capture_preview (Camera* camera, CameraFile* file, GPContext *context){
-
         /* this function is to slow; don't export it */
 	int fatal_error = 0;
 
