@@ -1,3 +1,24 @@
+/* dc240.c
+ *
+ * Copyright (C) 2001,2002 Hubert Figuiere <hfiguiere@teaser.fr>
+ * Copyright (C) 2000,2001,2002 Scott Fritzinger
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 /*
   Kodak DC 240/280/3400/5000 driver.
   Maintainer:
@@ -104,7 +125,7 @@ folder_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 {
 	Camera *camera = data;
 
-	return (dc240_get_folders (camera, list, folder, context));
+	return dc240_get_directory_list(camera, list, folder, 0x10, context);
 }
 
 static int
@@ -113,7 +134,7 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 {
 	Camera *camera = data;
 
-	return (dc240_get_filenames (camera, list, folder, context));
+	return dc240_get_directory_list(camera, list, folder, 0x00, context);
 }
 
 static int
