@@ -1,3 +1,24 @@
+/* library.c
+ *
+ * Copyright (C) 2001,2002 Hubert Figuiere <hfiguiere@teaser.fr>
+ * Copyright (C) 2000,2001,2002 Scott Fritzinger
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 /*
   Kodak DC 240/280/3400/5000 driver.
   Maintainer:
@@ -9,6 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
@@ -129,7 +151,7 @@ static int dc240_packet_write (Camera *camera, unsigned char *packet, int size,
 write_again:
     /* If retry, give camera some recup time */
     if (x > 0) {
-        GP_SYSTEM_SLEEP(SLEEP_TIMEOUT);
+        usleep(SLEEP_TIMEOUT * 1000);
     }
 
     /* Return error if too many retries */
@@ -237,7 +259,7 @@ static int dc240_wait_for_busy_completion (Camera *camera)
 	BUSY_RETRIES = 100
     };
     unsigned char p[8];
-    int retval;
+    int retval = 0;
     int x=0, done=0;
 
     /* Wait for command completion */
@@ -357,7 +379,7 @@ read_data_read_again:
             goto read_data_read_again;
 
         /* Set size for folder/file list command from 1st packet */
-        if ((cmd_packet[0]==0x99)&&(x==0)) {
+        if (cmd_packet && (cmd_packet[0]==0x99) && (x==0)) {
             *size = (packet[1] * 256 +
                      packet[2])* 20 + 2;
             t = (float)*size / (float)(block_size);
@@ -379,8 +401,7 @@ read_data_read_again:
     }
     gp_context_progress_stop (context, id);
     /* Read in command completed */
-    dc240_wait_for_completion(camera);
-    return (GP_OK);
+    return dc240_wait_for_completion(camera);
 }
 
 
@@ -497,7 +518,8 @@ int dc240_set_speed (Camera *camera, int speed)
          break;
     */
     default:
-        return (GP_ERROR);
+        retval = GP_ERROR;
+	goto fail;
     }
 
     retval = dc240_packet_write(camera, p, 8, 1);
@@ -508,7 +530,7 @@ int dc240_set_speed (Camera *camera, int speed)
     if (retval != GP_OK)
         goto fail;
 
-    GP_SYSTEM_SLEEP(300);
+    usleep(300 * 1000);
     retval = dc240_wait_for_completion(camera);
     if (retval != GP_OK)
 	goto fail;
@@ -709,8 +731,10 @@ int dc240_get_directory_list (Camera *camera, CameraList *list, const char *fold
 
     gp_file_new(&file);
     ret = dc240_packet_exchange(camera, file, p1, p2, &size, 256, context);
-    if (ret < 0)
+    if (ret < 0) {
+	gp_file_free (file);
         return ret;
+    }
     free(p1);
     free(p2);
 
@@ -773,6 +797,8 @@ int dc240_file_action (Camera *camera, int action, CameraFile *file,
         retval = dc240_packet_exchange(camera, file, cmd_packet, path_packet, &size, -1, context);
         break;
     default:
+        free(cmd_packet);
+        free(path_packet);
         return (GP_ERROR);
     }
 
