@@ -1,3 +1,23 @@
+/* dc3200.c
+ *
+ * Copyright (C) 2000,2001,2002 donn morrison - dmorriso@gulf.uvic.ca
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 /****************************************************
  * kodak dc3200 digital camera driver library       *
  * for gphoto2                                      *
@@ -16,6 +36,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
+#include <unistd.h>
 
 #include <gphoto2/gphoto2-library.h>
 
@@ -35,6 +56,11 @@
 #  define N_(String) (String)
 #endif
 
+/*
+ * FIXME: Use properly sized integer types. The dc3200 code used lots
+ *        of u_char, u_long, u_int, which may be wrong on non-32bit systems.
+ */
+
 #define CONTEXT_EXISTS _("There is currently an operation in progress. \
 This camera only supports one operation \
 at a time. Please wait until the current \
@@ -69,6 +95,7 @@ int camera_abilities (CameraAbilitiesList *list)
 	return (GP_OK);
 }
 
+static
 int init(Camera *camera)
 {
 	GPPortSettings settings;
@@ -117,18 +144,16 @@ int init(Camera *camera)
 
 static int camera_exit (Camera *camera, GPContext *context)
 {
-	if(camera->pl->context)
-	{
-		gp_context_error(context, CONTEXT_EXISTS);
-		return GP_ERROR;
-	}
-
 	if (camera->pl) {
+		if(camera->pl->context) {
+			gp_context_error(context, CONTEXT_EXISTS);
+			return GP_ERROR;
+		}
 		free (camera->pl);
 		camera->pl = NULL;
 	}
 
-	return (GP_OK);
+	return GP_OK;
 }
 
 int check_last_use(Camera *camera)
@@ -151,9 +176,9 @@ static int folder_list_func (CameraFilesystem *fs, const char *folder,
 			     GPContext *context)
 {
 	Camera 		*camera = user_data;
-	u_char		*data = NULL;
-	long		data_len = 0;
-	u_char		*ptr_data_buff;
+	unsigned char	*data = NULL;
+	long unsigned 	data_len = 0;
+	unsigned char	*ptr_data_buff;
 	char		filename[13], *ptr;
 	int		res, i;
 
@@ -207,7 +232,7 @@ static int folder_list_func (CameraFilesystem *fs, const char *folder,
 		}
 		
 		/* copy the filename */
-		strncpy(filename, ptr_data_buff, sizeof(filename));
+		strncpy(filename, (char *)ptr_data_buff, sizeof(filename));
 
 		/* chop off the trailing spaces and null terminate */
 		ptr = strchr(filename, 0x20);
@@ -232,9 +257,9 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
 			   GPContext *context)
 {
 	Camera		*camera = user_data;
-	u_char		*data = NULL;
-	long		data_len = 0;
-	u_char		*ptr_data_buff;
+	unsigned char	*data = NULL;
+	long unsigned	data_len = 0;
+	unsigned char	*ptr_data_buff;
 	char		filename[13];
 	int		res, i;
 
@@ -281,12 +306,12 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
 		}
 		
 		/* copy the first 8 bytes of filename */
-		strncpy(filename, ptr_data_buff, 8);
+		strncpy(filename, (char *)ptr_data_buff, 8);
 		filename[8] = 0;
 		/* add dot */
 		strcat(filename, ".");
 		/* copy extension, last 3 bytes*/
-		strncat(filename, ptr_data_buff+8, 3);
+		strncat(filename, (char *)ptr_data_buff+8, 3);
 		
 		if(!strstr(filename, ".JPG") && !strstr(filename, ".jpg")) {
 			ptr_data_buff += 20;
@@ -311,8 +336,8 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
 			  GPContext *context)
 {
 	Camera		*camera = user_data;
-	u_char		*data = NULL;
-	long		data_len = 0;
+	unsigned char	*data = NULL;
+	long unsigned	data_len = 0;
 	int		res;
 
 	if(camera->pl->context)
@@ -354,7 +379,7 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
 		return GP_ERROR;
 	}
 
-	gp_file_append (file, data, data_len);
+	gp_file_append (file, (char *)data, data_len);
 
 	free(data);
 	camera->pl->context = NULL;
@@ -367,8 +392,8 @@ get_info_func (CameraFilesystem *fs, const char *folder,
 	       GPContext *context)
 {
 	Camera		*camera = user_data;
-	u_char		*data = NULL;
-	long		data_len = 0;
+	unsigned char	*data = NULL;
+	long unsigned	data_len = 0;
 	int		res;
 	char		file[1024];
 
