@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #ifndef __mars_H__
@@ -44,6 +44,9 @@ int mars_read_picture_data (Camera *camera, Info *info,
 				GPPort *port, char *data, int size, int n);
 
 int mars_decompress (unsigned char *inp ,unsigned char *outp, int w, int h);
-
+int histogram (unsigned char *data, unsigned int size, int *htable_r, 
+                                        int *htable_g, int *htable_b);
+int mars_white_balance (unsigned char *data, unsigned int size, float saturation,
+                                        float image_gamma);
 #endif
 
