@@ -1,6 +1,6 @@
 /**********************************************************************
 *       Minolta Dimage V digital camera communication library         *
-*               Copyright  2000,2001 Gus Hartmann                  *
+*               Copyright 2000,2001 Gus Hartmann                      *
 *                                                                     *
 *    This program is free software; you can redistribute it and/or    *
 *    modify it under the terms of the GNU General Public License as   *
@@ -19,7 +19,7 @@
 *                                                                     *
 **********************************************************************/
 
-/* $Id: info.c 14608 2014-01-01 20:27:33Z marcusmeissner $ */
+/* $Id$ */
 
 #include "config.h"
 
@@ -53,11 +53,11 @@ int dimagev_get_camera_info(dimagev_t *dimagev) {
 		return GP_ERROR_IO;
 	}
 
-	if ( gp_port_write(dimagev->dev, p->buffer, p->length) < GP_OK ) {
+	if ( gp_port_write(dimagev->dev, (char *)p->buffer, p->length) < GP_OK ) {
 		GP_DEBUG( "dimagev_get_camera_info::unable to write packet");
 		free(p);
 		return GP_ERROR_IO;
-	} else if ( gp_port_read(dimagev->dev, &char_buffer, 1) < GP_OK ) {
+	} else if ( gp_port_read(dimagev->dev, (char *)&char_buffer, 1) < GP_OK ) {
 		GP_DEBUG( "dimagev_get_camera_info::no response from camera");
 		free(p);
 		return GP_ERROR_IO;
@@ -86,13 +86,13 @@ int dimagev_get_camera_info(dimagev_t *dimagev) {
 	}
 
 	char_buffer = DIMAGEV_EOT;
-	if ( gp_port_write(dimagev->dev, &char_buffer, 1) < GP_OK ) {
+	if ( gp_port_write(dimagev->dev, (char *)&char_buffer, 1) < GP_OK ) {
 		GP_DEBUG( "dimagev_get_camera_info::unable to send EOT");
 		free(p);
 		return GP_ERROR_IO;
 	}
 		
-	if ( gp_port_read(dimagev->dev, &char_buffer, 1) < GP_OK ) {
+	if ( gp_port_read(dimagev->dev, (char *)&char_buffer, 1) < GP_OK ) {
 		GP_DEBUG( "dimagev_get_camera_info::no response from camera");
 		free(p);
 		return GP_ERROR_IO;
