@@ -101,7 +101,7 @@ static uint16_t ptp_ptpip_event (PTPParams* params, PTPContainer* event, int wai
 
 /* send / receive functions */
 uint16_t
-ptp_ptpip_sendreq (PTPParams* params, PTPContainer* req)
+ptp_ptpip_sendreq (PTPParams* params, PTPContainer* req, int dataphase)
 {
 	int		ret;
 	int		len = 18+req->Nparam*4;
@@ -111,7 +111,11 @@ ptp_ptpip_sendreq (PTPParams* params, PTPContainer* req)
 
 	htod32a(&request[ptpip_type],PTPIP_CMD_REQUEST);
 	htod32a(&request[ptpip_len],len);
-	htod32a(&request[ptpip_cmd_dataphase],1);	/* FIXME: dataphase handling */
+	/* sending data = 2, receiving data or no data = 1 */
+	if ((dataphase&PTP_DP_DATA_MASK) == PTP_DP_SENDDATA)
+		htod32a(&request[ptpip_cmd_dataphase],2);
+	else
+		htod32a(&request[ptpip_cmd_dataphase],1);
 	htod16a(&request[ptpip_cmd_code],req->Code);
 	htod32a(&request[ptpip_cmd_transid],req->Transaction_ID);
 
@@ -149,7 +153,7 @@ ptp_ptpip_generic_read (PTPParams *params, int fd, PTPIPHeader *hdr, unsigned ch
 			perror ("read PTPIPHeader");
 			return PTP_RC_GeneralError;
 		}
-		GP_LOG_DATA ((char*)xhdr+curread, ret, "ptpip/generic_read data:");
+		GP_LOG_DATA ((char*)xhdr+curread, ret, "ptpip/generic_read header:");
 		curread += ret;
 		if (ret == 0) {
 			GP_LOG_E ("End of stream after reading %d bytes of ptpipheader", ret);
@@ -297,8 +301,8 @@ ptp_ptpip_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler
 		return ret;
 
 	if (dtoh32(hdr.type) == PTPIP_CMD_RESPONSE) { /* might happen if we have no data transfer due to error? */
-		GP_LOG_E ("Unexpected ptp response, code %x", dtoh32a(&xdata[8]));
-		return PTP_RC_GeneralError;
+		GP_LOG_E ("Unexpected ptp response, ptp code %x", dtoh16a(&xdata[0]));
+		return dtoh16a(&xdata[0]);
 	}
 	if (dtoh32(hdr.type) != PTPIP_START_DATA_PACKET) {
 		GP_LOG_E ("got reply type %d\n", dtoh32(hdr.type));
@@ -372,22 +376,37 @@ ptp_ptpip_getresp (PTPParams* params, PTPContainer* resp)
 	uint16_t 	ret;
 	int		n;
 
+retry:
 	ret = ptp_ptpip_cmd_read (params, &hdr, &data);
 	if (ret != PTP_RC_OK)
 		return ret;
 
-	resp->Code		= dtoh16a(&data[ptpip_resp_code]);
-	resp->Transaction_ID	= dtoh32a(&data[ptpip_resp_transid]);
-	n = (dtoh32(hdr.length) - sizeof(hdr) - ptpip_resp_param1)/sizeof(uint32_t);
-	switch (n) {
-	case 5: resp->Param5 = dtoh32a(&data[ptpip_resp_param5]);
-	case 4: resp->Param4 = dtoh32a(&data[ptpip_resp_param4]);
-	case 3: resp->Param3 = dtoh32a(&data[ptpip_resp_param3]);
-	case 2: resp->Param2 = dtoh32a(&data[ptpip_resp_param2]);
-	case 1: resp->Param1 = dtoh32a(&data[ptpip_resp_param1]);
-	case 0: break;
+	switch (dtoh32(hdr.type)) {
+	case PTPIP_END_DATA_PACKET:
+		GP_LOG_D("PTPIP_END_DATA_PACKET");
+		resp->Transaction_ID	= dtoh32a(&data[0]);
+		free (data);
+		data = NULL;
+		goto retry;
+	case PTPIP_CMD_RESPONSE:
+		GP_LOG_D("PTPIP_CMD_RESPONSE");
+		resp->Code		= dtoh16a(&data[ptpip_resp_code]);
+		resp->Transaction_ID	= dtoh32a(&data[ptpip_resp_transid]);
+		n = (dtoh32(hdr.length) - sizeof(hdr) - ptpip_resp_param1)/sizeof(uint32_t);
+		switch (n) {
+		case 5: resp->Param5 = dtoh32a(&data[ptpip_resp_param5]);
+		case 4: resp->Param4 = dtoh32a(&data[ptpip_resp_param4]);
+		case 3: resp->Param3 = dtoh32a(&data[ptpip_resp_param3]);
+		case 2: resp->Param2 = dtoh32a(&data[ptpip_resp_param2]);
+		case 1: resp->Param1 = dtoh32a(&data[ptpip_resp_param1]);
+		case 0: break;
+		default:
+			GP_LOG_E ("response got %d parameters?", n);
+			break;
+		}
+		break;
 	default:
-		GP_LOG_E ("response got %d parameters?", n);
+		GP_LOG_E ("response type %d packet?", dtoh32(hdr.type));
 		break;
 	}
 	free (data);
@@ -665,7 +684,7 @@ ptp_nikon_getptpipguid (unsigned char* guid) {
 int
 ptp_ptpip_connect (PTPParams* params, const char *address) {
 	char 		*addr, *s, *p;
-	int		port;
+	int		port, tries;
 	struct sockaddr_in	saddr;
 	uint16_t	ret;
 
@@ -731,16 +750,24 @@ ptp_ptpip_connect (PTPParams* params, const char *address) {
 		close (params->evtfd);
 		return translate_ptp_result (ret);
 	}
-	if (-1 == connect (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in))) {
+	/* seen on Ricoh Theta, camera is not immediately ready. try again two times. */
+	tries = 2;
+	do {
+		if (-1 != connect (params->evtfd, (struct sockaddr*)&saddr, sizeof(struct sockaddr_in)))
+			break;
+		if ((errno == ECONNREFUSED) && (tries--)) {
+			GP_LOG_D ("event connect failed, retrying after short wait");
+			usleep(100*1000);
+			continue;
+		}
 		GP_LOG_E ("could not connect event");
 		close (params->cmdfd);
 		close (params->evtfd);
 		return GP_ERROR_IO;
-	}
+	} while (1);
 	ret = ptp_ptpip_init_event_request (params);
-	if (ret != PTP_RC_OK) {
+	if (ret != PTP_RC_OK)
 		return translate_ptp_result (ret);
-	}
 	ret = ptp_ptpip_init_event_ack (params);
 	if (ret != PTP_RC_OK)
 		return translate_ptp_result (ret);
