@@ -71,15 +71,13 @@
 /* send / receive functions */
 
 uint16_t
-ptp_usb_sendreq (PTPParams* params, PTPContainer* req)
+ptp_usb_sendreq (PTPParams* params, PTPContainer* req, int dataphase)
 {
 	int res, towrite, do_retry = TRUE;
 	PTPUSBBulkContainer usbreq;
 	Camera *camera = ((PTPData *)params->data)->camera;
-	char buf[100];
 
-	ptp_render_opcode(params, req->Code, sizeof(buf),buf);
-	GP_LOG_D ("Sending PTP_OC 0x%0x / %s request...", req->Code, buf);
+	GP_LOG_D ("Sending PTP_OC 0x%0x (%s) request...", req->Code, ptp_get_opcode_name(params, req->Code));
 
 	/* build appropriate USB container */
 	usbreq.length=htod32(PTP_USB_BULK_REQ_LEN-
@@ -125,10 +123,8 @@ ptp_usb_senddata (PTPParams* params, PTPContainer* ptp,
 	int progressid = 0;
 	int usecontext = (size > CONTEXT_BLOCK_SIZE);
 	GPContext *context = ((PTPData *)params->data)->context;
-	char buf[100];
 
-	ptp_render_opcode(params, ptp->Code, sizeof(buf),buf);
-	GP_LOG_D ("Sending PTP_OC 0x%0x / %s data...", ptp->Code, buf);
+	GP_LOG_D ("Sending PTP_OC 0x%0x (%s) data...", ptp->Code, ptp_get_opcode_name(params, ptp->Code));
 	/* build appropriate USB container */
 	usbdata.length	= htod32(PTP_USB_BULK_HDR_LEN+size);
 	usbdata.type	= htod16(PTP_USB_CONTAINER_DATA);
@@ -258,10 +254,8 @@ ptp_usb_getdata (PTPParams* params, PTPContainer* ptp, PTPDataHandler *handler)
 	Camera		*camera = ((PTPData *)params->data)->camera;
 	int		report_progress, progress_id = 0, do_retry = TRUE, res = GP_OK;
 	GPContext *context = ((PTPData *)params->data)->context;
-	char buf[100];
 
-	ptp_render_opcode(params, ptp->Code, sizeof(buf),buf);
-	GP_LOG_D ("Reading PTP_OC 0x%0x / %s data...", ptp->Code, buf);
+	GP_LOG_D ("Reading PTP_OC 0x%0x (%s) data...", ptp->Code, ptp_get_opcode_name(params, ptp->Code));
 	PTP_CNT_INIT(usbdata);
 
 	ret = ptp_usb_getpacket (params, &usbdata, &bytes_read);
@@ -416,7 +410,7 @@ ptp_usb_getresp (PTPParams* params, PTPContainer* resp)
 	PTPUSBBulkContainer	usbresp;
 	/*GPContext		*context = ((PTPData *)params->data)->context;*/
 
-	GP_LOG_D ("Reading PTP_OC 0x%0x response...", resp->Code);
+	GP_LOG_D ("Reading PTP_OC 0x%0x (%s) response...", resp->Code, ptp_get_opcode_name(params, resp->Code));
 	PTP_CNT_INIT(usbresp);
 	/* read response, it should never be longer than sizeof(usbresp) */
 	ret = ptp_usb_getpacket(params, &usbresp, &rlen);
