@@ -1,6 +1,6 @@
 /* g3.c
  *
- * Copyright  2003 Marcus Meissner <marcus@jet.franken.de>
+ * Copyright 2003 Marcus Meissner <marcus@jet.franken.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -56,7 +56,7 @@ g3_channel_read(GPPort *port, int *channel, char **buffer, int *len)
 	unsigned char xbuf[0x800];
 	int tocopy, ret, curlen;
 
-	ret = gp_port_read(port, xbuf, 0x800);
+	ret = gp_port_read(port, (char *)xbuf, 0x800);
 	if (ret < GP_OK) { 
 		gp_log(GP_LOG_ERROR, "g3", "read error in g3_channel_read\n");
 		return ret;
@@ -117,18 +117,23 @@ g3_channel_read_bytes(
 		rest = (rest + 9 + 3) & ~3;
 		if (rest < 0x800) rest = 0x800;
 
-		ret = gp_port_read(port, xbuf, rest);
+		ret = gp_port_read(port, (char *)xbuf, rest);
 		if (ret < GP_OK) {
 			gp_log(GP_LOG_ERROR, "g3", "read error in g3_channel_read\n");
+			gp_context_progress_stop (context, id);
+			free(xbuf);
 			return ret;
 		}
 		if (ret != rest) {
 			gp_log(GP_LOG_ERROR, "g3", "read error in g3_channel_read\n");
+			gp_context_progress_stop (context, id);
+			free(xbuf);
 			return ret;
 		}
 
 		if ((xbuf[2] != 0xff) || (xbuf[3] != 0xff)) {
 			gp_log(GP_LOG_ERROR, "g3", "first bytes do not match.\n");
+			gp_context_progress_stop (context, id);
 			free(xbuf);
 			return GP_ERROR_IO;
 		}
@@ -480,8 +485,8 @@ delete_file_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -508,8 +513,8 @@ rmdir_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -536,8 +541,8 @@ mkdir_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -601,7 +606,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 			sprintf(t+strlen(t), _("Internal memory: %d MB total, %d MB free.\n"), space/1024/1024, sfree/1024/1024);
 		}
 	}
-	if (buf) free (buf);
+	free (buf);
 	return (GP_OK);
 }
 
@@ -683,7 +688,7 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		}
 	}
 out:
-	if (reply) free(reply);
+	free(reply);
 	free(cmd);
 
 	return (GP_OK);
