@@ -1,6 +1,6 @@
 /* sierra_usbwrap.c
  *
- * Copyright 2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright 2002 Lutz Mueller <lutz@users.sourceforge.net>
  * Copyright 2012-2013 Marcus Meissner <marcus@jet.franken.de>
  *
  * This library is free software; you can redistribute it and/or
@@ -319,7 +319,7 @@ usb_wrap_RDY(gp_port* dev, unsigned int type)
    	 sense_buffer, sizeof(sense_buffer), (char*)&msg, sizeof(msg));
    if (ret<GP_OK)
       GP_DEBUG( "usb_wrap_RDY *** FAILED" );
-   return GP_OK;
+   return ret;
 }
 
 static int
@@ -344,9 +344,7 @@ usb_wrap_STAT(gp_port* dev, unsigned int type)
    if (ret < GP_OK)
    {
       GP_DEBUG( "usb_wrap_STAT *** FAILED" );
-      if (ret < GP_OK)
-	return ret;
-      return GP_ERROR;
+      return ret;
    }
 
    xlen = uw_value(sizeof(msg));
@@ -424,9 +422,7 @@ usb_wrap_SIZE(gp_port* dev, unsigned int type, uw32_t* size)
    if (ret < GP_OK)
    {
       GP_DEBUG( "usb_wrap_SIZE *** FAILED" );
-      if (ret < GP_OK)
-	return ret;
-      return GP_ERROR;
+      return ret;
    }
    xlen = uw_value(sizeof(msg));
    if (!UW_EQUAL(msg.length, xlen) || !UW_EQUAL(msg.packet_type, UW_PACKET_DATA))
