@@ -1,6 +1,6 @@
 /* sierra.c:
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright 2001 Lutz Mueller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -537,8 +537,9 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	char *jpeg_data = NULL;
 	int jpeg_size;
 	const char *data, *mime_type;
-	long int size;
-	int download_size, audio_info[8], transferred;
+	long unsigned int size;
+	int download_size, audio_info[8];
+	unsigned int transferred;
 
 	/*
 	 * Get the file number from the CameraFileSystem.
@@ -599,7 +600,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
 	/* Get the file */
 	CHECK_STOP (camera, sierra_get_string_register (camera, regd, n,
-					file, NULL, &download_size,  context));
+					file, NULL, (unsigned int *)&download_size,  context));
 	if (download_size == 0) {
 		/*
 		 * Assume a failure. At least coolpix 880 returns no error
@@ -752,7 +753,7 @@ put_file_func (CameraFilesystem * fs, const char *folder, const char *filename,
 	char *picture_folder;
 	int ret;
 	const char *data_file;
-	long data_size;
+	long unsigned int data_size;
 	int available_memory;
 
 	GP_DEBUG ("*** put_file_func");
@@ -1685,7 +1686,7 @@ camera_get_config_epson (Camera *camera, CameraWidget **window, GPContext *conte
 		gp_widget_add_choice (child, _("Italian"));
 		gp_widget_add_choice (child, _("Japanese"));
 		gp_widget_add_choice (child, _("Spanish"));
-		gp_widget_add_choice (child, _("Portugese"));
+		gp_widget_add_choice (child, _("Portuguese"));
                 switch (value) {
                 case 1: strcpy (t, _("Korean"));
                         break;
@@ -1701,7 +1702,7 @@ camera_get_config_epson (Camera *camera, CameraWidget **window, GPContext *conte
 			break;
 		case 8: strcpy (t, _("Spanish"));
 			break;
-		case 9: strcpy (t, _("Portugese"));
+		case 9: strcpy (t, _("Portuguese"));
 			break;
                 default:
                         sprintf (t, _("%i (unknown)"), value);
@@ -1878,7 +1879,7 @@ camera_set_config_epson (Camera *camera, CameraWidget *window, GPContext *contex
 			i = 7;
 		} else if (strcmp (value, _("Spanish")) == 0) {
 			i = 8;
-		} else if (strcmp (value, _("Portugese")) == 0) {
+		} else if (strcmp (value, _("Portuguese")) == 0) {
 			i = 9;
 		} else
 			return (GP_ERROR_NOT_SUPPORTED);
@@ -1942,15 +1943,20 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *c)
 	}
 	/* Get all the string-related info */
 
-	if (sierra_get_string_register (camera, 27, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 27, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Camera Model: %s\n"), t);
-	if (sierra_get_string_register (camera, 48, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 48, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Manufacturer: %s\n"), t);
-	if (sierra_get_string_register (camera, 22, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 22, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Camera ID: %s\n"), t);
-	if (sierra_get_string_register (camera, 25, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 25, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Serial Number: %s\n"), t);
-	if (sierra_get_string_register (camera, 26, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 26, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Software Rev.: %s\n"), t);
 
 	/* Get all the integer information */
@@ -2007,7 +2013,8 @@ storage_info_func (CameraFilesystem *fs,
 	sif->fields |= GP_STORAGEINFO_FILESYSTEMTYPE;
 	sif->fstype  = GP_STORAGEINFO_FST_DCF;
 
-	if (sierra_get_string_register (camera, 25, 0, NULL, t, &v, c) >= 0) {
+	if (sierra_get_string_register (camera, 25, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0) {
 		sif->fields |= GP_STORAGEINFO_LABEL;
 		strcpy (sif->label, t);
 	}
