@@ -1,14 +1,30 @@
 /*
  * soundvision.c
  *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details. 
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
+ *
  * For cameras using the Clarity2 chip made by Soundvision Inc.
  * Made entirely w/o Soundvision's help.  They would not give
  * documentation.  Reverse-engineered from usb-traces.
  * 
- * Copyright  2002-2003 Vince Weaver <vince@deater.net>
+ * Copyright 2002-2003 Vince Weaver <vince@deater.net>
  * 
  * Originally based on the digita driver 
- * Copyright  1999-2000 Johannes Erdfelt, VA Linux Systems
+ * Copyright 1999-2000 Johannes Erdfelt, VA Linux Systems
  */
 
 #include "config.h"
@@ -282,7 +298,7 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
    
     if (!data) return GP_ERROR;
 
-    gp_file_set_data_and_size (file, data, size);
+    gp_file_set_data_and_size (file, (char *)data, size);
        /* Maybe skip below if EXIF data present? */
    
        /* As far as I know we only support JPG and MOV */
@@ -385,7 +401,7 @@ static int put_file_func (CameraFilesystem *fs, const char *folder, const char *
    
     Camera *camera=data;
     const char *data_file;
-    long data_size;
+    long unsigned int data_size;
    
     /*
      * Upload the file to the camera. Use gp_file_get_data_and_size, etc.
