@@ -1,6 +1,22 @@
 /*
  * tiger_fastflicks.c
  *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details. 
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
+ *
  *  Commands specific to soundvision camears with usbid
  *  0x0919:0x0100 and possibly others.
  * 
@@ -29,6 +45,7 @@
 #ifdef OS2
 #include <db.h>
 #endif
+#include <unistd.h>
 
 #include <gphoto2/gphoto2.h>
 #include "gphoto2-endian.h"
