@@ -192,7 +192,7 @@ camera_capture (Camera *camera, CameraCaptureType type,
 
 	/* Not all our cameras support capture */
 	gp_camera_get_abilities (camera, &a);
-	if (!a.operations & GP_OPERATION_CAPTURE_IMAGE)
+	if (!(a.operations & GP_OPERATION_CAPTURE_IMAGE))
 		return GP_ERROR_NOT_SUPPORTED;
 
 	if (cam_has_flash(camera->pl))
@@ -348,7 +348,8 @@ get_file_func (CameraFilesystem *fs, const char *folder,
 
 	Camera *camera = user_data;
 	unsigned char *data = NULL;
-	int size, number, filetype, flash_file_count = 0;
+	int number, filetype, flash_file_count = 0;
+	unsigned int size;
 
 	CHECK (number =
 	       gp_filesystem_number (camera->fs, folder, filename, context));
@@ -409,7 +410,7 @@ get_file_func (CameraFilesystem *fs, const char *folder,
 	}
 	if (!data)
 		return GP_ERROR;
-	return gp_file_set_data_and_size (file, data, size);
+	return gp_file_set_data_and_size (file, (char *)data, size);
 }
 
 static int
