@@ -2,7 +2,7 @@
 /* spca50x_sdram.c - Gphoto2 library for cameras with sunplus   */
 /*             spca50x chips                                    */
 /*                                                              */
-/* Copyright  2002, 2003 Till Adam                             */
+/* Copyright 2002, 2003 Till Adam                               */
 /*                                                              */
 /* Author: Till Adam <till@adam-lilienthal.de>                  */
 /*                                                              */
@@ -20,16 +20,19 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
+#define _BSD_SOURCE
+
 #include "config.h"
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <gphoto2.h>
-#include <gphoto2-endian.h>
+#include <unistd.h>
+#include <gphoto2/gphoto2.h>
+#include "gphoto2-endian.h"
 
 #include "spca50x.h"
 #include "spca50x-sdram.h"
@@ -117,7 +120,7 @@ spca50x_sdram_get_file_count_and_fat_count (CameraPrivateLibrary * lib,
 		sleep (1);
 		CHECK (gp_port_usb_msg_read
 				(lib->gpdev, 0, 0, 0xe15,
-				 (uint8_t *) & lib->num_files_on_sdram, 1));
+				 (char *) & lib->num_files_on_sdram, 1));
 		LE32TOH (lib->num_files_on_sdram);
 
 		/*  get fatscount */
@@ -126,12 +129,12 @@ spca50x_sdram_get_file_count_and_fat_count (CameraPrivateLibrary * lib,
 		sleep (1);
 		CHECK (gp_port_usb_msg_read
 				(lib->gpdev, 0, 0, 0x0e19,
-				 (uint8_t *) & lower, 1));
+				 (char *)&lower, 1));
 		CHECK (gp_port_usb_msg_read
 				(lib->gpdev, 0, 0, 0x0e20,
-				 (uint8_t *) & upper, 1));
+				 (char *)&upper, 1));
 
-		lib->num_fats = ((upper & 0xFF << 8) | (lower & 0xFF));
+		lib->num_fats = (((upper & 0xFF) << 8) | (lower & 0xFF));
 	} else {
 		while (1) {
 			CHECK (spca50x_sdram_get_fat_page (lib, lib->num_fats,
@@ -212,7 +215,7 @@ spca50x_get_image (CameraPrivateLibrary * lib, uint8_t ** buf,
 	uint8_t qIndex = 0, format;
 	uint32_t start;
 	uint8_t *mybuf;
-	int size, o_size, file_size;
+	int size, o_size, file_size, ret;
 	int omit_escape = 0;
 
 	p = g_file->fat;
@@ -252,7 +255,11 @@ spca50x_get_image (CameraPrivateLibrary * lib, uint8_t ** buf,
 		return GP_ERROR_NO_MEMORY;
 
 	if (lib->bridge == BRIDGE_SPCA504) {
-		CHECK (spca50x_download_data (lib, start, size, mybuf));
+		ret = spca50x_download_data (lib, start, size, mybuf);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 	} else if (lib->bridge == BRIDGE_SPCA500) {
 		/* find the file index on the camera */
 		int index;
@@ -260,18 +267,28 @@ spca50x_get_image (CameraPrivateLibrary * lib, uint8_t ** buf,
 		index = (g_file->fat - lib->fats) / SPCA50X_FAT_PAGE_SIZE;
 		spca50x_reset (lib);
 		/* trigger upload of image at that index */
-		CHECK (gp_port_usb_msg_write (lib->gpdev, 0x06,
-					      0x70FF - index, 0x01, NULL, 0));
+		ret = gp_port_usb_msg_write (lib->gpdev, 0x06,
+					      0x70FF - index, 0x01, NULL, 0);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 		sleep (1);
-		CHECK (gp_port_read (lib->gpdev, mybuf, size));
+		ret = gp_port_read (lib->gpdev, (char *)mybuf, size);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 		/* the smallest ones are in a different format */
 		if ((p[20] & 0xff) == 2)
 			format = 0x22;
 	}
 	/* now build a jpeg */
 	lp_jpg = malloc (file_size);
-	if (!lp_jpg)
+	if (!lp_jpg) {
+		free (mybuf);
 		return GP_ERROR_NO_MEMORY;
+	}
 	create_jpeg_from_data (lp_jpg, mybuf, qIndex, g_file->width,
 			       g_file->height, format, o_size, &file_size,
 			       0, omit_escape);
@@ -288,7 +305,7 @@ static int
 spca50x_get_avi (CameraPrivateLibrary * lib, uint8_t ** buf,
 		unsigned int *len, struct SPCA50xFile *g_file)
 {
-	int i, j, length;
+	int i, j, length, ret;
 	int frame_count = 0, frames_per_fat = 0, fn = 0;
 	int size = 0;
 	int file_size;
@@ -351,7 +368,12 @@ spca50x_get_avi (CameraPrivateLibrary * lib, uint8_t ** buf,
 		return GP_ERROR_NO_MEMORY;
 	}
 
-	CHECK (spca50x_download_data (lib, start, size, mybuf));
+	ret = spca50x_download_data (lib, start, size, mybuf);
+	if (ret < GP_OK) {
+		free (avi_index);
+		free (mybuf);
+		return ret;
+	}
 
 	/* Now write our data to a file with an avi header */
 	file_size = size + SPCA50X_AVI_HEADER_LENGTH
@@ -360,8 +382,11 @@ spca50x_get_avi (CameraPrivateLibrary * lib, uint8_t ** buf,
 		+ 1024 * 10 * frame_count;
 
 	avi = malloc (file_size);
-	if (!avi)
+	if (!avi) {
+		free (avi_index);
+		free (mybuf);
 		return GP_ERROR_NO_MEMORY;
+	}
 
 	start_of_file = avi;
 
@@ -498,7 +523,7 @@ spca50x_get_avi_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 	uint32_t start;
 	uint8_t *mybuf;
 	int size, o_size, file_size;
-	int w, h;
+	int ret;
 
 	/* FIXME */
 	if (lib->bridge == BRIDGE_SPCA500)
@@ -515,8 +540,6 @@ spca50x_get_avi_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 		(p[52] & 0xff) * 0x10000 + (p[51] & 0xff) * 0x100 +
 		(p[50] & 0xff);
 	qIndex = p[7] & 0x0f;
-	w = (int) ((p[8] & 0xFF) * 16);
-	h = (int) ((p[9] & 0xFF) * 16);
 
 	/* align */
 	if (size % 64 != 0)
@@ -529,12 +552,18 @@ spca50x_get_avi_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 	if (!mybuf)
 		return GP_ERROR_NO_MEMORY;
 
-	CHECK (spca50x_download_data (lib, start, size, mybuf));
+	ret = spca50x_download_data (lib, start, size, mybuf);
+	if (ret < GP_OK) {
+		free (mybuf);
+		return ret;
+	}
 
 	/* now build a jpeg */
 	lp_jpg = malloc (file_size);
-	if (!lp_jpg)
+	if (!lp_jpg) {
+		free (mybuf);
 		return GP_ERROR_NO_MEMORY;
+	}
 
 	create_jpeg_from_data (lp_jpg, mybuf, qIndex, g_file->width,
 			       g_file->height, 0x22, o_size, &file_size, 0, 0);
@@ -559,7 +588,7 @@ spca50x_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 	unsigned int t_width, t_height;
 	uint8_t *yuv_p;
 	uint8_t *rgb_p;
-	int headerlength;
+	int headerlength, ret;
 
 	p = g_file->fat;
 
@@ -581,7 +610,11 @@ spca50x_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 	mybuf = malloc (size);
 
 	if (lib->bridge == BRIDGE_SPCA504) {
-		CHECK (spca50x_download_data (lib, start, size, mybuf));
+		ret = spca50x_download_data (lib, start, size, mybuf);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 	} else if (lib->bridge == BRIDGE_SPCA500) {
 		/* find the file index on the camera */
 		int index;
@@ -589,18 +622,28 @@ spca50x_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 		index = (g_file->fat - lib->fats) / SPCA50X_FAT_PAGE_SIZE;
 		spca50x_reset (lib);
 		/* trigger upload of thumbnail at that index */
-		CHECK (gp_port_usb_msg_write (lib->gpdev, 0x06,
-					      0x70FF - index, 0x09, NULL, 0));
+		ret = gp_port_usb_msg_write (lib->gpdev, 0x06,
+					      0x70FF - index, 0x09, NULL, 0);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 		sleep (1);
-		CHECK (gp_port_read (lib->gpdev, mybuf, size));
+		ret = gp_port_read (lib->gpdev, (char *)mybuf, size);
+		if (ret < GP_OK) {
+			free (mybuf);
+			return ret;
+		}
 	}
 	*len = t_width * t_height * 3 + headerlength;
 	*buf = malloc (*len);
-	if (!*buf)
+	if (!*buf) {
+		free (mybuf);
 		return (GP_ERROR_NO_MEMORY);
+	}
 
 	tmp = *buf;
-	snprintf (tmp, *len, "P6 %d %d 255\n", t_width, t_height);
+	snprintf ((char*)tmp, *len, "P6 %d %d 255\n", t_width, t_height);
 	tmp += headerlength;
 
 	yuv_p = mybuf;
@@ -655,7 +698,7 @@ spca50x_sdram_get_info (CameraPrivateLibrary * lib)
 
 		CHECK (gp_port_usb_msg_read
 		       (lib->gpdev, 0, 0, SPCA50X_REG_DramType,
-			(uint8_t *) & dramtype, 1));
+			(char *) & dramtype, 1));
 		dramtype &= 0xFF;
 	}
 
@@ -709,7 +752,7 @@ spca50x_is_idle (CameraPrivateLibrary * lib)
 	int mode;
 
 	CHECK (gp_port_usb_msg_read
-	       (lib->gpdev, 0, 0, SPCA50X_REG_CamMode, (uint8_t *) & mode, 1));
+	       (lib->gpdev, 0, 0, SPCA50X_REG_CamMode, (char *) & mode, 1));
 
 	return mode == SPCA50X_CamMode_Idle ? 1 : 0;
 }
@@ -748,13 +791,13 @@ spca50x_download_data (CameraPrivateLibrary * lib, uint32_t start,
 
 	CHECK (gp_port_usb_msg_read
 	       (lib->gpdev, 0, 0, SPCA50X_REG_VlcAddressL,
-		(uint8_t *) & vlcAddressL, 1));
+		(char *) & vlcAddressL, 1));
 	CHECK (gp_port_usb_msg_read
 	       (lib->gpdev, 0, 0, SPCA50X_REG_VlcAddressM,
-		(uint8_t *) & vlcAddressM, 1));
+		(char *) & vlcAddressM, 1));
 	CHECK (gp_port_usb_msg_read
 	       (lib->gpdev, 0, 0, SPCA50X_REG_VlcAddressH,
-		(uint8_t *) & vlcAddressH, 1));
+		(char *) & vlcAddressH, 1));
 
 	foo = start & 0xFF;
 	CHECK (gp_port_usb_msg_write
@@ -774,7 +817,7 @@ spca50x_download_data (CameraPrivateLibrary * lib, uint32_t start,
 	       (lib->gpdev, 0, SPCA50X_TrigDramFifo, SPCA50X_REG_Trigger, NULL,
 		0));
 
-	CHECK (gp_port_read (lib->gpdev, buf, size));
+	CHECK (gp_port_read (lib->gpdev, (char *)buf, size));
 
 	CHECK (gp_port_usb_msg_write
 	       (lib->gpdev, 0, vlcAddressL, SPCA50X_REG_VlcAddressL, NULL, 0));
@@ -830,7 +873,7 @@ spca50x_get_FATs (CameraPrivateLibrary * lib, int dramtype)
 		       (lib->gpdev, 0x05, 0x00, 0x07, NULL, 0));
 		sleep (1);
 		CHECK (gp_port_read
-		       (lib->gpdev, lib->fats,
+		       (lib->gpdev, (char *)lib->fats,
 			lib->num_fats * SPCA50X_FAT_PAGE_SIZE));
 	}
 
@@ -849,13 +892,13 @@ spca50x_get_FATs (CameraPrivateLibrary * lib, int dramtype)
 		} else {
 			/* its an image */
 			if (type == 0x00 || type == 0x01) {
-				snprintf (buf, 13, "Image%03d.jpg",
+				snprintf ((char*)buf, 13, "Image%03d.jpg",
 					  ++lib->num_images);
 				lib->files[file_index].mime_type =
 					SPCA50X_FILE_TYPE_IMAGE;
 			} else if ((type == 0x08) || (type == 0x03)) {
 				/* its the start of an avi */
-				snprintf (buf, 13, "Movie%03d.avi",
+				snprintf ((char*)buf, 13, "Movie%03d.avi",
 					  ++lib->num_movies);
 				lib->files[file_index].mime_type =
 					SPCA50X_FILE_TYPE_AVI;
@@ -863,7 +906,7 @@ spca50x_get_FATs (CameraPrivateLibrary * lib, int dramtype)
 			lib->files[file_index].fat = p;
 			lib->files[file_index].fat_start = index;
 			lib->files[file_index].fat_end = index;
-			lib->files[file_index].name = strdup (buf);
+			lib->files[file_index].name = strdup ((char*)buf);
 			if (lib->bridge == BRIDGE_SPCA504) {
 				lib->files[file_index].width =
 					(p[8] & 0xFF) * 16;
