@@ -1,7 +1,7 @@
 #ifndef __SQ905_H__
 #define __SQ905_H__
 
-#include <libgphoto2_port/gphoto2-port.h>
+#include <gphoto2/gphoto2-port.h>
 
 /* A 'picture' is a single standalone picture.
  * A 'clip' is an autoshoot clip.
@@ -41,13 +41,13 @@ int sq_access_reg 		     (GPPort *, int reg);
 int sq_reset             		(GPPort *);
 int sq_rewind                        (GPPort *, CameraPrivateLibrary *);
 int sq_init                          (GPPort *, CameraPrivateLibrary *);
-unsigned char *sq_read_picture_data  (GPPort *, unsigned char *data, int size);
+int sq_read_picture_data  (GPPort *, unsigned char *data, int size);
 int sq_delete_all                    (GPPort *, CameraPrivateLibrary *);
 
 /* Those functions don't need data transfer with the camera */
 int sq_get_num_frames                (CameraPrivateLibrary *, int entry);
-unsigned 
-char sq_get_comp_ratio      	     (CameraPrivateLibrary *, int entry);
+ 
+int sq_get_comp_ratio      	     (CameraPrivateLibrary *, int entry);
 int sq_get_picture_width             (CameraPrivateLibrary *, int entry);
 int sq_is_clip                       (CameraPrivateLibrary *, int entry);
 
@@ -57,10 +57,6 @@ sq_preprocess		(SQModel model, int comp_ratio,
 				unsigned char *data, int w, int h);
 int
 sq_decompress 		(SQModel model, unsigned char *output, unsigned char *data, 
-				int w, int h, int n);
-int sq_postprocess	(CameraPrivateLibrary *priv, 
-				int width, int height, 
-				unsigned char* rgb, int n);
-
+				int w, int h);
 #endif
 
