@@ -56,7 +56,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 # include <iconv.h>
 # include <langinfo.h>
 #endif
@@ -67,8 +67,10 @@
 #define PUT 0
 #define GET 1
 
+#if 0
 static int quiet = 0;
-#ifdef HAVE_ICONV
+#endif
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 static iconv_t cd_locale_to_latin1;
 static iconv_t cd_latin1_to_locale;
 #endif
@@ -90,7 +92,7 @@ backslash(char *path) {
 		*s='\\';
 }
 
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 static char*
 strdup_to_latin1 (const char *str) {
 	size_t	ret, srclen, dstlen, ndstlen;
@@ -287,6 +289,7 @@ do_cmd_turbo(Camera *camera, char *state, GPContext *context)
 	return GP_ERROR_IO;
 }
 
+#if 0
 static int
 do_cmd_reset(Camera *camera, GPContext *context)
 {
@@ -317,6 +320,7 @@ do_cmd_reset(Camera *camera, GPContext *context)
 	}
 	return GP_ERROR_IO;
 }
+#endif
 
 static int
 do_cmd_ready(Camera *camera, GPContext *context)
@@ -339,7 +343,6 @@ do_cmd_ready(Camera *camera, GPContext *context)
 
 	case FAIL:
 		gp_log (GP_LOG_ERROR, "topfield", "ERROR: Device reports %s\n", decode_error(&reply));
-		get_u32(&reply.data);
 		break;
 
 	default:
@@ -349,6 +352,7 @@ do_cmd_ready(Camera *camera, GPContext *context)
 	return GP_OK;
 }
 
+#if 0
 static int
 do_cancel(Camera *camera, GPContext *context)
 {
@@ -379,7 +383,7 @@ do_cancel(Camera *camera, GPContext *context)
 	}
 	return GP_ERROR_IO;
 }
-
+#endif
 
 static void
 decode_dir(Camera *camera, struct tf_packet *p, int listdirs, CameraList *list)
@@ -468,6 +472,7 @@ decode_and_get_info(Camera *camera, const char *folder, struct tf_packet *p, con
     }
 }
 
+#if 0
 static int
 do_hdd_rename(Camera *camera, char *srcPath, char *dstPath, GPContext *context)
 {
@@ -533,7 +538,7 @@ static void finalStats(uint64_t bytes, time_t startTime)
                 ((bytes * 8.0) / delta) / (1000.0 * 1000.0));
     }
 }
-
+#endif
 
 static int
 camera_config_get (Camera *camera, CameraWidget **window, GPContext *context) 
@@ -1193,7 +1198,7 @@ CameraFilesystemFuncs fsfuncs = {
 static int
 camera_exit (Camera *camera, GPContext *context)
 {
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	iconv_close (cd_latin1_to_locale);
 	iconv_close (cd_locale_to_latin1);
 #endif
@@ -1222,7 +1227,7 @@ camera_init (Camera *camera, GPContext *context)
 	camera->pl = calloc (sizeof (CameraPrivateLibrary),1);
 	if (!camera->pl) return GP_ERROR_NO_MEMORY;
 
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	curloc = nl_langinfo (CODESET);
 	if (!curloc) curloc="UTF-8";
 	cd_latin1_to_locale = iconv_open(curloc, "iso-8859-1");
