@@ -10,6 +10,7 @@ extern int get_config_value_string (Camera *, const char *, char **, GPContext *
 extern int set_config_value_string (Camera *, const char *, const char *, GPContext *);
 int canon_enable_capture (Camera *camera, int onoff, GPContext *context);
 
-extern int camera_auto_focus (Camera *list, GPContext *context);
+extern int camera_auto_focus (Camera *list, GPContext *context, int onoff);
+extern int camera_eosviewfinder (Camera *list, GPContext *context, int onoff);
 extern int camera_manual_focus (Camera *list, int tgt, GPContext *context);
 #endif
