@@ -1,6 +1,6 @@
 /** \file gphoto2-context.c
  *
- * \author Copyright 2001 Lutz Mller <lutz@users.sourceforge.net>
+ * \author Copyright 2001 Lutz Mueller <lutz@users.sourceforge.net>
  *
  * \par License
  * This library is free software; you can redistribute it and/or
@@ -75,10 +75,9 @@ gp_context_new (void)
 {
 	GPContext *context;
 
-	context = malloc (sizeof (GPContext));
+	context = calloc (1, sizeof (GPContext));
 	if (!context)
 		return (NULL);
-	memset (context, 0, sizeof (GPContext));
 
 	context->ref_count = 1;
 
@@ -102,9 +101,6 @@ gp_context_ref (GPContext *context)
 static void
 gp_context_free (GPContext *context)
 {
-	if (!context)
-		return;
-
 	free (context);
 }
 
@@ -160,51 +156,21 @@ gp_context_progress_start (GPContext *context, float target,
 			   const char *format, ...)
 {
 	va_list args;
-	unsigned int id;
-#ifdef HAVE_VA_COPY
-	va_list xargs;
-#else
-#define xargs args
-#endif
-	int strsize = 1000;
 	char *str;
-	int n;
+	unsigned int id;
 
 	if (!context)
 		return (0);
 	if (!context->progress_start_func)
 		return (0);
 
-	str = malloc(strsize);
-	if (!str) {
-		return 0;
-	}
 	va_start (args, format);
-#ifdef HAVE_VA_COPY
-	va_copy (xargs, args);
-#endif
-	n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-	va_end (xargs);
-#endif
-	if (n+1>strsize) {
-		free (str);
-		str = malloc(n+1);
-		if (!str) { 
-			va_end (args);
-			return 0;
-		}
-		strsize = n+1;
-#ifdef HAVE_VA_COPY
-		va_copy (xargs, args);
-#endif
-		n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-		va_end (xargs);
-#endif
-	}
+	str = gpi_vsnprintf(format, args);
 	va_end (args);
 
+	if (!str)
+		return 0;
+
 	id = context->progress_start_func (context, target, str,
 				context->progress_func_data);
 	free (str);
@@ -237,45 +203,17 @@ void
 gp_context_error (GPContext *context, const char *format, ...)
 {
 	va_list args;
-#ifdef HAVE_VA_COPY
-	va_list xargs;
-#endif
-	int strsize = 1000;
 	char *str;
-	int n;
 
-	str = malloc(strsize);
-	if (!str) {
-		return;
-	}
 	va_start (args, format);
-#ifdef HAVE_VA_COPY
-	va_copy (xargs, args);
-#endif
-	n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-	va_end (xargs);
-#endif
-	if (n+1>strsize) {
-		free (str);
-		str = malloc(n+1);
-		if (!str) { 
-			va_end (args);
-			return;
-		}
-		strsize = n+1;
-#ifdef HAVE_VA_COPY
-		va_copy (xargs, args);
-#endif
-		n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-		va_end (xargs);
-#endif
-	}
+	str = gpi_vsnprintf(format, args);
 	va_end (args);
 
+	if (!str)
+		return;
+
 	/* Log the error message */
-	gp_log (GP_LOG_ERROR, "context", "%s", str);
+	gp_log( GP_LOG_ERROR, __func__, "%s", str);
 
 	if (context && context->error_func)
 		context->error_func (context, str, context->error_func_data);
@@ -286,45 +224,17 @@ void
 gp_context_status (GPContext *context, const char *format, ...)
 {
 	va_list args;
-#ifdef HAVE_VA_COPY
-	va_list xargs;
-#endif
-	int strsize = 1000;
 	char *str;
-	int n;
 
-	str = malloc(strsize);
-	if (!str) {
-		return;
-	}
 	va_start (args, format);
-#ifdef HAVE_VA_COPY
-	va_copy (xargs, args);
-#endif
-	n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-	va_end (xargs);
-#endif
-	if (n+1>strsize) {
-		free (str);
-		str = malloc(n+1);
-		if (!str) { 
-			va_end (args);
-			return;
-		}
-		strsize = n+1;
-#ifdef HAVE_VA_COPY
-		va_copy (xargs, args);
-#endif
-		n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-		va_end (xargs);
-#endif
-	}
+	str = gpi_vsnprintf(format, args);
 	va_end (args);
 
+	if (!str)
+		return;
+
 	/* Log the status message */
-	gp_log (GP_LOG_DEBUG, "context", "%s", str);
+	GP_LOG_D ("%s", str);
 
 	if (context && context->status_func)
 		context->status_func (context, str, context->status_func_data);
@@ -347,46 +257,17 @@ void
 gp_context_message (GPContext *context, const char *format, ...)
 {
 	va_list args;
-#ifdef HAVE_VA_COPY
-	va_list xargs;
-#endif
-	int strsize = 1000;
 	char *str;
-	int n;
 
-	str = malloc(strsize);
-	if (!str) {
-		va_end (xargs);
-		return;
-	}
 	va_start (args, format);
-#ifdef HAVE_VA_COPY
-	va_copy (xargs, args);
-#endif
-	n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-	va_end (xargs);
-#endif
-	if (n+1>strsize) {
-		free (str);
-		str = malloc(n+1);
-		if (!str) { 
-			va_end (args);
-			return;
-		}
-		strsize = n+1;
-#ifdef HAVE_VA_COPY
-		va_copy (xargs, args);
-#endif
-		n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-		va_end (xargs);
-#endif
-	}
+	str = gpi_vsnprintf(format, args);
 	va_end (args);
 
+	if (!str)
+		return;
+
 	/* Log the message */
-	gp_log (GP_LOG_DEBUG, "context", "%s", str);
+	GP_LOG_D ("%s", str);
 
 	if (context && context->message_func)
 		context->message_func (context, str, context->message_func_data);
@@ -411,43 +292,15 @@ gp_context_question (GPContext *context, const char *format, ...)
 {
 	GPContextFeedback feedback;
 	va_list args;
-#ifdef HAVE_VA_COPY
-	va_list xargs;
-#endif
-	int strsize = 1000;
 	char *str;
-	int n;
 
-	str = malloc(strsize);
-	if (!str) {
-		return GP_CONTEXT_FEEDBACK_OK;
-	}
 	va_start (args, format);
-#ifdef HAVE_VA_COPY
-	va_copy (xargs, args);
-#endif
-	n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-	va_end (xargs);
-#endif
-	if (n+1>strsize) {
-		free (str);
-		str = malloc(n+1);
-		if (!str) { 
-			va_end (args);
-			return GP_CONTEXT_FEEDBACK_OK;
-		}
-		strsize = n+1;
-#ifdef HAVE_VA_COPY
-		va_copy (xargs, args);
-#endif
-		n = vsnprintf (str, strsize, format, xargs);
-#ifdef HAVE_VA_COPY
-		va_end (xargs);
-#endif
-	}
+	str = gpi_vsnprintf(format, args);
 	va_end (args);
 
+	if (!str)
+		return GP_CONTEXT_FEEDBACK_OK;
+
 	feedback = GP_CONTEXT_FEEDBACK_OK;
 	if (context && context->question_func)
 		feedback = context->question_func (context, str, context->question_func_data);
