@@ -29,8 +29,6 @@
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-port-log.h>
 
-#define CHECK_NULL(r)        {if (!(r)) return (GP_ERROR_BAD_PARAMETERS);}
-
 /**
  * CameraWidget:
  *
@@ -97,10 +95,9 @@ gp_widget_new (CameraWidgetType type, const char *label,
 {
 	static int i = 0;
 
-	CHECK_NULL (label && widget);
+	C_PARAMS (label && widget);
 
-	*widget = (CameraWidget*) malloc (sizeof (CameraWidget));
-	memset (*widget, 0, sizeof (CameraWidget));
+	C_MEM (*widget = calloc (1, sizeof (CameraWidget)));
 
 	(*widget)->type = type;
 	strcpy ((*widget)->label, label);
@@ -135,7 +132,7 @@ int
 gp_widget_free (CameraWidget *widget)
 {
 	int x;
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	/* Free children recursively */
 	if ((widget->type == GP_WIDGET_WINDOW) ||
@@ -147,9 +144,7 @@ gp_widget_free (CameraWidget *widget)
 	for (x = 0; x < widget->choice_count; x++)
 		free (widget->choice[x]);
 	free (widget->choice);
-
-        if (widget->value_string)
-		free (widget->value_string);
+	free (widget->value_string);
 	free (widget);
 	return (GP_OK);
 }
@@ -164,7 +159,7 @@ gp_widget_free (CameraWidget *widget)
 int
 gp_widget_ref (CameraWidget *widget) 
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->ref_count += 1;
 
@@ -181,7 +176,7 @@ gp_widget_ref (CameraWidget *widget)
 int
 gp_widget_unref (CameraWidget *widget) 
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->ref_count -= 1;
 
@@ -202,7 +197,7 @@ gp_widget_unref (CameraWidget *widget)
 int
 gp_widget_get_info (CameraWidget *widget, const char **info)
 {
-	CHECK_NULL (widget && info);
+	C_PARAMS (widget && info);
 
 	*info = widget->info;
 	return (GP_OK);
@@ -220,7 +215,7 @@ gp_widget_get_info (CameraWidget *widget, const char **info)
 int
 gp_widget_set_info (CameraWidget *widget, const char *info)
 {
-	CHECK_NULL (widget && info);
+	C_PARAMS (widget && info);
 
 	strcpy (widget->info, info);
 	return (GP_OK);
@@ -237,7 +232,7 @@ gp_widget_set_info (CameraWidget *widget, const char *info)
 int
 gp_widget_get_name (CameraWidget *widget, const char **name)
 {
-	CHECK_NULL (widget && name);
+	C_PARAMS (widget && name);
 
 	*name = widget->name;
 	return (GP_OK);
@@ -254,7 +249,7 @@ gp_widget_get_name (CameraWidget *widget, const char **name)
 int
 gp_widget_set_name (CameraWidget *widget, const char *name)
 {
-	CHECK_NULL (widget && name);
+	C_PARAMS (widget && name);
 
 	strcpy (widget->name, name);
 	return (GP_OK);
@@ -273,7 +268,7 @@ gp_widget_set_name (CameraWidget *widget, const char *name)
 int
 gp_widget_get_id (CameraWidget *widget, int *id)
 {
-	CHECK_NULL (widget && id);
+	C_PARAMS (widget && id);
 
 	*id = widget->id;
 	return (GP_OK);
@@ -293,7 +288,7 @@ gp_widget_get_id (CameraWidget *widget, int *id)
 int
 gp_widget_set_changed (CameraWidget *widget, int changed)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->changed = changed;
 	return (GP_OK);
@@ -314,7 +309,7 @@ gp_widget_set_changed (CameraWidget *widget, int changed)
 int
 gp_widget_set_readonly (CameraWidget *widget, int readonly)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->readonly = readonly;
 	return (GP_OK);
@@ -331,7 +326,7 @@ gp_widget_set_readonly (CameraWidget *widget, int readonly)
 int
 gp_widget_get_readonly (CameraWidget *widget, int *readonly) 
 {
-	CHECK_NULL (widget && readonly);
+	C_PARAMS (widget && readonly);
 
 	*readonly = widget->readonly;
 	return (GP_OK);
@@ -348,7 +343,7 @@ gp_widget_get_readonly (CameraWidget *widget, int *readonly)
 int
 gp_widget_get_type (CameraWidget *widget, CameraWidgetType *type) 
 {
-	CHECK_NULL (widget && type);
+	C_PARAMS (widget && type);
 
 	*type = widget->type;
 	return (GP_OK);
@@ -365,7 +360,7 @@ gp_widget_get_type (CameraWidget *widget, CameraWidgetType *type)
 int
 gp_widget_get_label (CameraWidget *widget, const char **label) 
 {
-	CHECK_NULL (widget && label);
+	C_PARAMS (widget && label);
 
 	*label = widget->label;
 	return (GP_OK);
@@ -388,7 +383,7 @@ gp_widget_get_label (CameraWidget *widget, const char **label)
 int
 gp_widget_set_value (CameraWidget *widget, const void *value) 
 {
-	CHECK_NULL (widget && value);
+	C_PARAMS (widget && value);
 
         switch (widget->type) {
 	case GP_WIDGET_BUTTON:
@@ -397,9 +392,9 @@ gp_widget_set_value (CameraWidget *widget, const void *value)
 	case GP_WIDGET_MENU:
 	case GP_WIDGET_RADIO:
         case GP_WIDGET_TEXT:
-		gp_log (GP_LOG_DEBUG, "gphoto2-widget", "Setting value of widget "
-			"'%s' to '%s'...", widget->label, (char*) value);
-			if (widget->value_string) {
+		GP_LOG_D ("Setting value of widget '%s' to '%s'...",
+			widget->label, (char*) value);
+		if (widget->value_string) {
                 	if (strcmp (widget->value_string, (char*) value))
                     		widget->changed = 1;
                 	free (widget->value_string);
@@ -438,7 +433,7 @@ gp_widget_set_value (CameraWidget *widget, const void *value)
 int
 gp_widget_get_value (CameraWidget *widget, void *value) 
 {
-	CHECK_NULL (widget && value);
+	C_PARAMS (widget && value);
 
         switch (widget->type) {
 	case GP_WIDGET_BUTTON:
@@ -474,20 +469,13 @@ gp_widget_get_value (CameraWidget *widget, void *value)
 int
 gp_widget_append (CameraWidget *widget, CameraWidget *child) 
 {
-	CameraWidget **newlist;
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	/* Return if they can't have any children */
-        if ((widget->type != GP_WIDGET_WINDOW) && 
-	    (widget->type != GP_WIDGET_SECTION))
-		return (GP_ERROR_BAD_PARAMETERS);
+        C_PARAMS ((widget->type == GP_WIDGET_WINDOW) ||
+                  (widget->type == GP_WIDGET_SECTION));
 
-	if (widget->children_count)
-		newlist = realloc(widget->children,sizeof(CameraWidget*)*(widget->children_count+1));
-	else
-		newlist = malloc(sizeof(CameraWidget*));
-	if (!newlist) return (GP_ERROR_NO_MEMORY);
-	widget->children = newlist;
+	C_MEM (widget->children = realloc(widget->children, sizeof(CameraWidget*)*(widget->children_count+1)));
 	widget->children[widget->children_count] = child;
 	widget->children_count += 1;
 	child->parent = widget;
@@ -508,21 +496,14 @@ int
 gp_widget_prepend (CameraWidget *widget, CameraWidget *child) 
 {
 	int x;
-	CameraWidget**	newlist;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	/* Return if they can't have any children */
-	if ((widget->type != GP_WIDGET_WINDOW) && 
-	    (widget->type != GP_WIDGET_SECTION))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS ((widget->type == GP_WIDGET_WINDOW) ||
+		  (widget->type == GP_WIDGET_SECTION));
 
-	if (widget->children_count)
-		newlist = realloc(widget->children,sizeof(CameraWidget*)*(widget->children_count+1));
-	else
-		newlist = malloc(sizeof(CameraWidget*));
-	if (!newlist) return (GP_ERROR_NO_MEMORY);
-	widget->children = newlist;
+	C_MEM (widget->children = realloc(widget->children, sizeof(CameraWidget*)*(widget->children_count+1)));
 
 	/* Shift down 1 */
 	for (x = widget->children_count; x > 0; x--)
@@ -547,7 +528,7 @@ gp_widget_prepend (CameraWidget *widget, CameraWidget *child)
 int
 gp_widget_count_children (CameraWidget *widget) 
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	return (widget->children_count);
 }
@@ -565,10 +546,8 @@ int
 gp_widget_get_child (CameraWidget *widget, int child_number, 
 		     CameraWidget **child) 
 {
-	CHECK_NULL (widget && child);
-
-	if (child_number >= widget->children_count)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && child);
+	C_PARAMS (child_number < widget->children_count);
 
 	*child = widget->children[child_number];
 	return (GP_OK);
@@ -589,7 +568,7 @@ gp_widget_get_child_by_label (CameraWidget *widget, const char *label,
 {
 	int x;
 
-	CHECK_NULL (widget && label && child);
+	C_PARAMS (widget && label && child);
 
 	if (strcmp (widget->label, label) == 0) {
 		*child = widget;
@@ -625,7 +604,7 @@ gp_widget_get_child_by_id (CameraWidget *widget, int id, CameraWidget **child)
 {
 	int x;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	if (widget->id == id) {
 		*child = widget;
@@ -661,7 +640,7 @@ gp_widget_get_child_by_name (CameraWidget *widget, const char *name,
 {
 	int x;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	if (!strcmp (widget->name, name)) {
 		*child = widget;
@@ -694,7 +673,7 @@ gp_widget_get_child_by_name (CameraWidget *widget, const char *name,
 int
 gp_widget_get_parent (CameraWidget *widget, CameraWidget **parent)
 {
-	CHECK_NULL (widget && parent);
+	C_PARAMS (widget && parent);
 
 	*parent = widget->parent;
 
@@ -712,7 +691,7 @@ gp_widget_get_parent (CameraWidget *widget, CameraWidget **parent)
 int
 gp_widget_get_root (CameraWidget *widget, CameraWidget **root) 
 {
-	CHECK_NULL (widget && root);
+	C_PARAMS (widget && root);
 
 	if (widget->parent) 
 		return (gp_widget_get_root (widget->parent, root));
@@ -735,10 +714,8 @@ gp_widget_get_root (CameraWidget *widget, CameraWidget **root)
 int
 gp_widget_set_range (CameraWidget *range, float min, float max, float increment)
 {
-	CHECK_NULL (range);
-	
-	if (range->type != GP_WIDGET_RANGE)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (range);
+	C_PARAMS (range->type == GP_WIDGET_RANGE);
 
 	range->min = min;
 	range->max = max;
@@ -761,9 +738,8 @@ int
 gp_widget_get_range (CameraWidget *range, float *min, float *max, 
 		     float *increment) 
 {
-	CHECK_NULL (range && min && max && increment);
-	if (range->type != GP_WIDGET_RANGE)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (range && min && max && increment);
+	C_PARAMS (range->type == GP_WIDGET_RANGE);
 
 	*min = range->min;
 	*max = range->max;
@@ -783,20 +759,11 @@ gp_widget_get_range (CameraWidget *range, float *min, float *max,
 int
 gp_widget_add_choice (CameraWidget *widget, const char *choice) 
 {
-	char **choices;
-	CHECK_NULL (widget && choice);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && choice);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
 
-	if (widget->choice_count) {
-		choices = realloc (widget->choice, sizeof(char*)*(widget->choice_count+1));
-	} else {
-		choices = malloc (sizeof(char*));
-	}
-	if (!choices) return (GP_ERROR_NO_MEMORY);
-
-	widget->choice = choices;
+	C_MEM (widget->choice = realloc (widget->choice, sizeof(char*)*(widget->choice_count+1)));
 	widget->choice[widget->choice_count] = strdup(choice);
 	widget->choice_count += 1;
 	return (GP_OK);
@@ -812,10 +779,9 @@ gp_widget_add_choice (CameraWidget *widget, const char *choice)
 int
 gp_widget_count_choices (CameraWidget *widget) 
 {
-	CHECK_NULL (widget);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
 
 	return (widget->choice_count);
 }
@@ -833,13 +799,10 @@ int
 gp_widget_get_choice (CameraWidget *widget, int choice_number, 
 		      const char **choice) 
 {
-	CHECK_NULL (widget && choice);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
-
-	if (choice_number >= widget->choice_count)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && choice);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
+	C_PARAMS (choice_number < widget->choice_count);
 
 	*choice = widget->choice[choice_number];
 	return (GP_OK);
@@ -860,7 +823,7 @@ gp_widget_changed (CameraWidget *widget)
 {
         int val;
 
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
         val = widget->changed;
         widget->changed = 0;
