@@ -1,8 +1,8 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* gphoto2-port-usb.c
  *
- * Copyright  2001 Lutz Mller <lutz@users.sf.net>
- * Copyright  1999-2000 Johannes Erdfelt <johannes@erdfelt.com>
+ * Copyright 2001 Lutz Mueller <lutz@users.sf.net>
+ * Copyright 1999-2000 Johannes Erdfelt <johannes@erdfelt.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -216,10 +216,7 @@ gp_port_library_list (GPPortInfoList *list)
 
 static int gp_port_usb_init (GPPort *port)
 {
-	port->pl = malloc (sizeof (GPPortPrivateLibrary));
-	if (!port->pl)
-		return (GP_ERROR_NO_MEMORY);
-	memset (port->pl, 0, sizeof (GPPortPrivateLibrary));
+	C_MEM (port->pl = calloc (1, sizeof (GPPortPrivateLibrary)));
 
 	port->pl->config = port->pl->interface = port->pl->altsetting = -1;
 
@@ -233,10 +230,8 @@ static int gp_port_usb_init (GPPort *port)
 static int
 gp_port_usb_exit (GPPort *port)
 {
-	if (port->pl) {
-		free (port->pl);
-		port->pl = NULL;
-	}
+	free (port->pl);
+	port->pl = NULL;
 
 	return (GP_OK);
 }
@@ -249,13 +244,11 @@ gp_port_usb_open (GPPort *port)
 	int ret;
 	char name[64];
 
-	gp_log (GP_LOG_DEBUG,"libusb","gp_port_usb_open(%p)", port);
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	GP_LOG_D ("gp_port_usb_open(%p)", port);
+	C_PARAMS (port);
 	if (!port->pl->d) {
 		ret = gp_port_usb_find_path_lib(port);
-		if (!port->pl->d)
-			return GP_ERROR_BAD_PARAMETERS;
+		C_PARAMS (port->pl->d);
 	}
 
         /*
@@ -275,7 +268,7 @@ gp_port_usb_open (GPPort *port)
 		name, sizeof(name)
 	);
 	if (name[0] != 0)
-		gp_log (GP_LOG_DEBUG,"libusb",_("Device has driver '%s' attached."), name);
+		GP_LOG_D ("Device has driver '%s' attached.", name);
 	if (strstr(name,"usbfs") || strstr(name,"storage")) {
 		/* other gphoto instance most likely */
 		gp_port_set_error (port, _("Camera is already in use."));
@@ -283,7 +276,7 @@ gp_port_usb_open (GPPort *port)
 	}
 
 	if (ret >= 0) {
-		gp_log (GP_LOG_DEBUG,"libusb",_("Device has driver '%s' attached, detaching it now."), name);
+		GP_LOG_D ("Device has driver '%s' attached, detaching it now.", name);
 		ret = usb_detach_kernel_driver_np (port->pl->dh, port->settings.usb.interface);
 		if (ret < 0)
 			gp_port_set_error (port, _("Could not detach kernel driver '%s' of camera device."),name);
@@ -295,7 +288,7 @@ gp_port_usb_open (GPPort *port)
 	}
 #endif
 
-	gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
+	GP_LOG_D ("claiming interface %d", port->settings.usb.interface);
 	ret = usb_claim_interface (port->pl->dh,
 				   port->settings.usb.interface);
 	if (ret < 0) {
@@ -326,8 +319,7 @@ gp_port_usb_open (GPPort *port)
 static int
 gp_port_usb_close (GPPort *port)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	if (usb_release_interface (port->pl->dh,
 				   port->settings.usb.interface) < 0) {
@@ -369,7 +361,7 @@ gp_port_usb_close (GPPort *port)
 			command.ioctl_code = USBDEVFS_CONNECT;
 			command.data = NULL;
 			if (ioctl(fd, USBDEVFS_IOCTL, &command))
-				gp_log (GP_LOG_DEBUG,"libusb","reattach kernel driver failed");
+				GP_LOG_D ("reattach kernel driver failed");
 			close(fd);
 		}
 	}
@@ -392,8 +384,7 @@ gp_port_usb_clear_halt_lib(GPPort *port, int ep)
 {
 	int ret=0;
 
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	switch (ep) {
 	case GP_PORT_USB_ENDPOINT_IN :
@@ -418,8 +409,7 @@ gp_port_usb_write (GPPort *port, const char *bytes, int size)
 {
         int ret;
 
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+        C_PARAMS (port && port->pl->dh);
 
 	ret = usb_bulk_write (port->pl->dh, port->settings.usb.outep,
                            (char *) bytes, size, port->timeout);
@@ -434,8 +424,7 @@ gp_port_usb_read(GPPort *port, char *bytes, int size)
 {
 	int ret;
 
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	ret = usb_bulk_read(port->pl->dh, port->settings.usb.inep,
 			     bytes, size, port->timeout);
@@ -450,13 +439,12 @@ gp_port_usb_reset(GPPort *port)
 {
 	int ret;
 
-	gp_log (GP_LOG_DEBUG, "libusb", "Reseting port");
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	GP_LOG_D ("Reseting port");
+	C_PARAMS (port && port->pl->dh);
 
 	ret = usb_reset(port->pl->dh);
         if (ret < 0) {
-		gp_log (GP_LOG_ERROR, "libusb", "gp_port_reset: %d", ret);
+		GP_LOG_E ("gp_port_reset: %d", ret);
 		return GP_ERROR_IO_READ;
 	}
         return GP_OK;
@@ -467,8 +455,7 @@ gp_port_usb_check_int (GPPort *port, char *bytes, int size, int timeout)
 {
 	int ret;
 
-	if (!port || !port->pl->dh || timeout < 0)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh && timeout >= 0);
 
 	ret = usb_interrupt_read(port->pl->dh, port->settings.usb.intep,
 			     bytes, size, timeout);
@@ -484,8 +471,7 @@ static int
 gp_port_usb_msg_write_lib(GPPort *port, int request, int value, int index,
 	char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh,
 		USB_TYPE_VENDOR | USB_RECIP_DEVICE,
@@ -496,8 +482,7 @@ static int
 gp_port_usb_msg_read_lib(GPPort *port, int request, int value, int index,
 	char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh,
 		USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
@@ -512,8 +497,7 @@ static int
 gp_port_usb_msg_interface_write_lib(GPPort *port, int request, 
 	int value, int index, char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh, 
 		USB_TYPE_VENDOR | USB_RECIP_INTERFACE,
@@ -525,8 +509,7 @@ static int
 gp_port_usb_msg_interface_read_lib(GPPort *port, int request, 
 	int value, int index, char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh, 
 		USB_TYPE_VENDOR | USB_RECIP_INTERFACE | USB_ENDPOINT_IN,
@@ -542,8 +525,7 @@ static int
 gp_port_usb_msg_class_write_lib(GPPort *port, int request, 
 	int value, int index, char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh, 
 		USB_TYPE_CLASS | USB_RECIP_INTERFACE,
@@ -555,8 +537,7 @@ static int
 gp_port_usb_msg_class_read_lib(GPPort *port, int request, 
 	int value, int index, char *bytes, int size)
 {
-	if (!port || !port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port && port->pl->dh);
 
 	return usb_control_msg(port->pl->dh, 
 		USB_TYPE_CLASS | USB_RECIP_INTERFACE | USB_ENDPOINT_IN,
@@ -578,10 +559,9 @@ gp_port_usb_update (GPPort *port)
 {
 	int ret, ifacereleased = FALSE;
 
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
-	gp_log (GP_LOG_DEBUG, "libusb", "gp_port_usb_update(old int=%d, conf=%d, alt=%d) port %s, (new int=%d, conf=%d, alt=%d), port %s",
+	GP_LOG_D ("gp_port_usb_update(old int=%d, conf=%d, alt=%d) port %s, (new int=%d, conf=%d, alt=%d), port %s",
 		port->settings.usb.interface,
 		port->settings.usb.config,
 		port->settings.usb.altsetting,
@@ -602,35 +582,35 @@ gp_port_usb_update (GPPort *port)
 	memcpy(&port->settings.usb.port, &port->settings_pending.usb.port,
 		sizeof(port->settings.usb.port));
 
- 	if (!port->pl->dh)
-		return GP_ERROR_BAD_PARAMETERS;
+	if (!port->pl->dh)
+		return GP_OK; /* the port might not be opened, yet. that is ok */
 
 	memcpy(&port->settings.usb, &port->settings_pending.usb,
 		sizeof(port->settings.usb));
 
 	/* The interface changed. release the old, claim the new ... */
 	if (port->settings.usb.interface != port->pl->interface) {
-		gp_log (GP_LOG_DEBUG, "libusb", "changing interface %d -> %d",
+		GP_LOG_D ("changing interface %d -> %d",
 			port->pl->interface,
 			port->settings.usb.interface
 		);
 		if (usb_release_interface (port->pl->dh,
 					   port->pl->interface) < 0) {
-			gp_log (GP_LOG_DEBUG, "libusb","releasing the iface for config failed.");
+			GP_LOG_D ("releasing the iface for config failed.");
 			/* Not a hard error for now. -Marcus */
 		} else {
-			gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
+			GP_LOG_D ("claiming interface %d", port->settings.usb.interface);
 			ret = usb_claim_interface (port->pl->dh,
 						   port->settings.usb.interface);
 			if (ret < 0) {
-				gp_log (GP_LOG_DEBUG, "libusb","reclaiming the iface for config failed.");
+				GP_LOG_D ("reclaiming the iface for config failed.");
 				return GP_ERROR_IO_UPDATE;
 			}
 			port->pl->interface = port->settings.usb.interface;
 		}
 	}
 	if (port->settings.usb.config != port->pl->config) {
-		gp_log (GP_LOG_DEBUG, "libusb", "changing config %d -> %d",
+		GP_LOG_D ("changing config %d -> %d",
 			port->pl->config,
 			port->settings.usb.config
 		);
@@ -639,7 +619,7 @@ gp_port_usb_update (GPPort *port)
 		 */
 		if (usb_release_interface (port->pl->dh,
 					   port->settings.usb.interface) < 0) {
-			gp_log (GP_LOG_DEBUG, "libusb","releasing the iface for config failed.");
+			GP_LOG_D ("releasing the iface for config failed.");
 			ifacereleased = FALSE;
 		} else {
 			ifacereleased = TRUE;
@@ -656,21 +636,17 @@ gp_port_usb_update (GPPort *port)
 					   strerror(saved_errno));
 			return GP_ERROR_IO_UPDATE;	
 #endif
-			gp_log (GP_LOG_ERROR, "libusb","setting configuration from %d to %d failed with ret = %d, but continue...", port->pl->config, port->settings.usb.config, ret);
+			GP_LOG_E ("setting configuration from %d to %d failed with ret = %d, but continue...", port->pl->config, port->settings.usb.config, ret);
 		}
 
-		gp_log (GP_LOG_DEBUG, "libusb",
-			"Changed usb.config from %d to %d",
-			port->pl->config,
-			port->settings.usb.config);
+		GP_LOG_D ("Changed usb.config from %d to %d", port->pl->config, port->settings.usb.config);
 
 		if (ifacereleased) {
-			gp_log (GP_LOG_DEBUG,"libusb","claiming interface %d", port->settings.usb.interface);
+			GP_LOG_D ("claiming interface %d", port->settings.usb.interface);
 			ret = usb_claim_interface (port->pl->dh,
 						   port->settings.usb.interface);
-			if (ret < 0) {
-				gp_log (GP_LOG_DEBUG, "libusb","reclaiming the iface for config failed.");
-			}
+			if (ret < 0)
+				GP_LOG_D ("reclaiming the iface for config failed.");
 		}
 		/*
 		 * Copy at once if something else fails so that this
@@ -693,10 +669,7 @@ gp_port_usb_update (GPPort *port)
 			return GP_ERROR_IO_UPDATE;
 		}
 
-		gp_log (GP_LOG_DEBUG, "libusb",
-			"Changed usb.altsetting from %d to %d",
-			port->pl->altsetting,
-			port->settings.usb.altsetting);
+		GP_LOG_D ("Changed usb.altsetting from %d to %d", port->pl->altsetting, port->settings.usb.altsetting);
 		port->pl->altsetting = port->settings.usb.altsetting;
 	}
 
@@ -753,8 +726,7 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 	char *s;
 	char busname[64], devname[64];
 
-	if (!port)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (port);
 
 	s = strchr (port->settings.usb.port,':');
 	busname[0] = devname[0] = '\0';
@@ -799,10 +771,7 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 
 				port->pl->d = dev;
 
-				gp_log (GP_LOG_VERBOSE, "libusb",
-					"Looking for USB device "
-					"(vendor 0x%x, product 0x%x)... found.", 
-					idvendor, idproduct);
+				GP_LOG_D ("Looking for USB device (vendor 0x%x, product 0x%x)... found.", idvendor, idproduct);
 
 				/* Use the first config, interface and altsetting we find */
 				gp_port_usb_find_first_altsetting(dev, &config, &interface, &altsetting);
@@ -813,11 +782,9 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 
 					if (dev->config[config].interface[interface].altsetting[altsetting].bInterfaceClass
 					    == USB_CLASS_MASS_STORAGE) {
-						gp_log (GP_LOG_VERBOSE, "libusb",
-							_("USB device (vendor 0x%x, product 0x%x) is a mass"
+						GP_LOG_D ("USB device (vendor 0x%x, product 0x%x) is a mass"
 							  " storage device, and might not function with gphoto2."
-							  " Reference: %s"),
-							idvendor, idproduct, URL_USB_MASSSTORAGE);
+							  " Reference: %s", idvendor, idproduct, URL_USB_MASSSTORAGE);
 					}
 					port->settings.usb.config = dev->config[config].bConfigurationValue;
 					port->settings.usb.interface = dev->config[config].interface[interface].altsetting[altsetting].bInterfaceNumber;
@@ -828,18 +795,15 @@ gp_port_usb_find_device_lib(GPPort *port, int idvendor, int idproduct)
 					port->settings.usb.intep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_INTERRUPT);
 
 					port->settings.usb.maxpacketsize = 0;
-					gp_log (GP_LOG_DEBUG, "libusb", "inep to look for is %02x", port->settings.usb.inep);
+					GP_LOG_D ("inep to look for is %02x", port->settings.usb.inep);
 					for (i=0;i<dev->config[config].interface[interface].altsetting[altsetting].bNumEndpoints;i++) {
 						if (port->settings.usb.inep == dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].bEndpointAddress) {
 							port->settings.usb.maxpacketsize = dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].wMaxPacketSize;
 							break;
 						}
 					}
-					gp_log (GP_LOG_VERBOSE, "libusb",
-						"Detected defaults: config %d, "
-						"interface %d, altsetting %d, "
-						"inep %02x, outep %02x, intep %02x, "
-						"class %02x, subclass %02x",
+					GP_LOG_D ("Detected defaults: config %d, interface %d, altsetting %d, "
+						  "inep %02x, outep %02x, intep %02x, class %02x, subclass %02x",
 						port->settings.usb.config,
 						port->settings.usb.interface,
 						port->settings.usb.altsetting,
@@ -872,28 +836,22 @@ gp_port_usb_find_path_lib(GPPort *port)
 	char *s;
 	char busname[64], devname[64];
 
-	if (!port)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (port);
 
 	s = strchr (port->settings.usb.port,':');
 	busname[0] = devname[0] = '\0';
-	if (!s || s[1] == '\0') {
-		/* generic usb: match ... can't do */
-		return GP_ERROR_BAD_PARAMETERS;
-	}
+	C_PARAMS (s && s[1] != '\0'); /* generic usb: match ... can't do */
+
 	if (s && (s[1] != '\0')) { /* usb:%d,%d */
 		strncpy(busname,s+1,sizeof(busname));
 		busname[sizeof(busname)-1] = '\0';
 
 		s = strchr(busname,',');
-		if (s) {
-			strncpy(devname, s+1,sizeof(devname));
-			devname[sizeof(devname)-1] = '\0';
-			*s = '\0';
-		} else {
-			/* generic usb: match ... can't do */
-			return GP_ERROR_BAD_PARAMETERS;
-		}
+		C_PARAMS (s); /* generic usb: match ... can't do */
+
+		strncpy(devname, s+1,sizeof(devname));
+		devname[sizeof(devname)-1] = '\0';
+		*s = '\0';
 	}
 	for (bus = usb_busses; bus; bus = bus->next) {
 		if (strcmp(busname, bus->dirname))
@@ -907,7 +865,7 @@ gp_port_usb_find_path_lib(GPPort *port)
 
 			port->pl->d = dev;
 
-			gp_log (GP_LOG_VERBOSE, "libusb", "Found device for path %s", port->settings.usb.port);
+			GP_LOG_D ("Found device for path %s", port->settings.usb.port);
 
 			/* Use the first config, interface and altsetting we find */
 			gp_port_usb_find_first_altsetting(dev, &config, &interface, &altsetting);
@@ -925,18 +883,15 @@ gp_port_usb_find_path_lib(GPPort *port)
 				port->settings.usb.intep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_INTERRUPT);
 
 				port->settings.usb.maxpacketsize = 0;
-				gp_log (GP_LOG_DEBUG, "libusb", "inep to look for is %02x", port->settings.usb.inep);
+				GP_LOG_D ("inep to look for is %02x", port->settings.usb.inep);
 				for (i=0;i<dev->config[config].interface[interface].altsetting[altsetting].bNumEndpoints;i++) {
 					if (port->settings.usb.inep == dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].bEndpointAddress) {
 						port->settings.usb.maxpacketsize = dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].wMaxPacketSize;
 						break;
 					}
 				}
-				gp_log (GP_LOG_VERBOSE, "libusb",
-					"Detected defaults: config %d, "
-					"interface %d, altsetting %d, "
-					"inep %02x, outep %02x, intep %02x, "
-					"class %02x, subclass %02x",
+				GP_LOG_D ("Detected defaults: config %d, interface %d, altsetting %d, "
+					  "inep %02x, outep %02x, intep %02x, class %02x, subclass %02x",
 					port->settings.usb.config,
 					port->settings.usb.interface,
 					port->settings.usb.altsetting,
@@ -1032,9 +987,9 @@ gp_port_usb_match_mtp_device(struct usb_device *dev,int *configno, int *interfac
 					if (ret < 3)
 						continue;
 					if (strcmp((char *) buf, "MTP") == 0) {
-						gp_log (GP_LOG_DEBUG, "mtp matcher", "Configuration %d, interface %d, altsetting %d:\n", i, j, k);
-						gp_log (GP_LOG_DEBUG, "mtp matcher", "   Interface description contains the string \"MTP\"\n");
-						gp_log (GP_LOG_DEBUG, "mtp matcher", "   Device recognized as MTP, no further probing.\n");
+						GP_LOG_D ("Configuration %d, interface %d, altsetting %d:\n", i, j, k);
+						GP_LOG_D ("   Interface description contains the string \"MTP\"\n");
+						GP_LOG_D ("   Device recognized as MTP, no further probing.\n");
 						goto found;
 					}
 				}
@@ -1043,34 +998,34 @@ gp_port_usb_match_mtp_device(struct usb_device *dev,int *configno, int *interfac
 	}
 	/* get string descriptor at 0xEE */
 	ret = usb_get_descriptor (devh, 0x03, 0xee, buf, sizeof(buf));
-	if (ret > 0) gp_log_data("get_MS_OSD",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_OSD");
 	if (ret < 10) goto errout;
 	if (!((buf[2] == 'M') && (buf[4]=='S') && (buf[6]=='F') && (buf[8]=='T')))
 		goto errout;
 	cmd = buf[16];
 	ret = usb_control_msg (devh, USB_ENDPOINT_IN|USB_RECIP_DEVICE|USB_TYPE_VENDOR, cmd, 0, 4, buf, sizeof(buf), 1000);
 	if (ret == -1) {
-		gp_log (GP_LOG_ERROR, "mtp matcher", "control message says %d\n", ret);
+		GP_LOG_E ("control message says %d\n", ret);
 		goto errout;
 	}
 	if (buf[0] != 0x28) {
-		gp_log (GP_LOG_ERROR, "mtp matcher", "ret is %d, buf[0] is %x\n", ret, buf[0]);
+		GP_LOG_E ("ret is %d, buf[0] is %x\n", ret, buf[0]);
 		goto errout;
 	}
-	if (ret > 0) gp_log_data("get_MS_ExtDesc",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_ExtDesc");
 	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
-		gp_log (GP_LOG_ERROR, "mtp matcher", "buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
+		GP_LOG_E ("buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
 		goto errout;
 	}
 	ret = usb_control_msg (devh, USB_ENDPOINT_IN|USB_RECIP_DEVICE|USB_TYPE_VENDOR, cmd, 0, 5, buf, sizeof(buf), 1000);
 	if (ret == -1) goto errout;
 	if (buf[0] != 0x28) {
-		gp_log (GP_LOG_ERROR, "mtp matcher", "ret is %d, buf[0] is %x\n", ret, buf[0]);
+		GP_LOG_E ("ret is %d, buf[0] is %x\n", ret, buf[0]);
 		goto errout;
 	}
-	if (ret > 0) gp_log_data("get_MS_ExtProp",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_ExtProp");
 	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
-		gp_log (GP_LOG_ERROR, "mtp matcher", "buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
+		GP_LOG_E ("buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
 		goto errout;
 	}
 
@@ -1080,19 +1035,19 @@ found:
 	/* Now chose a nice interface for us to use ... Just take the first. */
 
 	if (dev->descriptor.bNumConfigurations > 1)
-		gp_log (GP_LOG_ERROR, "mtp matcher", "The device has %d configurations!\n", dev->descriptor.bNumConfigurations);
+		GP_LOG_E ("The device has %d configurations!\n", dev->descriptor.bNumConfigurations);
 	for (i = 0; i < dev->descriptor.bNumConfigurations; i++) {
 		struct usb_config_descriptor *config =
 			&dev->config[i];
 
 		if (config->bNumInterfaces > 1)
-			gp_log (GP_LOG_ERROR, "mtp matcher", "The configuration has %d interfaces!\n", config->bNumInterfaces);
+			GP_LOG_E ("The configuration has %d interfaces!\n", config->bNumInterfaces);
 		for (i1 = 0; i1 < config->bNumInterfaces; i1++) {
 			struct usb_interface *interface =
 				&config->interface[i1];
 
 			if (interface->num_altsetting > 1)
-				gp_log (GP_LOG_ERROR, "mtp matcher", "The interface has %d altsettings!\n", interface->num_altsetting);
+				GP_LOG_E ("The interface has %d altsettings!\n", interface->num_altsetting);
 			for (i2 = 0; i2 < interface->num_altsetting; i2++) {
 				*configno = i;
 				*interfaceno = i1;
@@ -1167,8 +1122,7 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 	char *s;
 	char busname[64], devname[64];
 
-	if (!port)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (port);
 
 	busname[0] = devname[0] = '\0';
 	s = strchr (port->settings.usb.port,':');
@@ -1191,8 +1145,7 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 	 * Should the USB layer report that ? I don't know.
 	 * Better to check here.
 	 */
-	if (!class)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (class);
 
 	for (bus = usb_busses; bus; bus = bus->next) {
 		if ((busname[0] != '\0') && strcmp(busname, bus->dirname))
@@ -1203,20 +1156,14 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 
 			if ((devname[0] != '\0') && strcmp(devname, dev->filename))
 				continue;
-			gp_log (GP_LOG_VERBOSE, "gphoto2-port-usb",
-				"Looking for USB device "
-				"(class 0x%x, subclass, 0x%x, protocol 0x%x)...", 
-				class, subclass, protocol);
+			GP_LOG_D ("Looking for USB device (class 0x%x, subclass, 0x%x, protocol 0x%x)...", class, subclass, protocol);
 
 			ret = gp_port_usb_match_device_by_class(dev, class, subclass, protocol, &config, &interface, &altsetting);
 			if (!ret)
 				continue;
 
 			port->pl->d = dev;
-			gp_log (GP_LOG_VERBOSE, "libusb",
-				"Found USB class device "
-				"(class 0x%x, subclass, 0x%x, protocol 0x%x)", 
-				class, subclass, protocol);
+			GP_LOG_D ("Found USB class device (class 0x%x, subclass, 0x%x, protocol 0x%x)", class, subclass, protocol);
 			/* Set the defaults */
 			if (dev->config) {
 				int i;
@@ -1229,18 +1176,15 @@ gp_port_usb_find_device_by_class_lib(GPPort *port, int class, int subclass, int
 				port->settings.usb.outep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_OUT, USB_ENDPOINT_TYPE_BULK);
 				port->settings.usb.intep = gp_port_usb_find_ep(dev, config, interface, altsetting, USB_ENDPOINT_IN, USB_ENDPOINT_TYPE_INTERRUPT);
 				port->settings.usb.maxpacketsize = 0;
-				gp_log (GP_LOG_DEBUG, "libusb", "inep to look for is %02x", port->settings.usb.inep);
+				GP_LOG_D ("inep to look for is %02x", port->settings.usb.inep);
 				for (i=0;i<dev->config[config].interface[interface].altsetting[altsetting].bNumEndpoints;i++) {
 					if (port->settings.usb.inep == dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].bEndpointAddress) {
 						port->settings.usb.maxpacketsize = dev->config[config].interface[interface].altsetting[altsetting].endpoint[i].wMaxPacketSize;
 						break;
 					}
 				}
-				gp_log (GP_LOG_VERBOSE, "libusb",
-					"Detected defaults: config %d, "
-					"interface %d, altsetting %d, "
-					"idVendor ID %04x, idProduct %04x, "
-					"inep %02x, outep %02x, intep %02x",
+				GP_LOG_D ("Detected defaults: config %d, interface %d, altsetting %d, "
+					  "idVendor ID %04x, idProduct %04x, inep %02x, outep %02x, intep %02x",
 					port->settings.usb.config,
 					port->settings.usb.interface,
 					port->settings.usb.altsetting,
@@ -1268,10 +1212,9 @@ gp_port_library_operations (void)
 {
 	GPPortOperations *ops;
 
-	ops = malloc (sizeof (GPPortOperations));
+	ops = calloc (1, sizeof (GPPortOperations));
 	if (!ops)
 		return (NULL);
-	memset (ops, 0, sizeof (GPPortOperations));
 
 	ops->init   = gp_port_usb_init;
 	ops->exit   = gp_port_usb_exit;
