@@ -2,16 +2,15 @@ var NAVTREEINDEX0 =
 {
 "__stdint_8h_source.html":[2,0,2,0],
 "ahd__bayer_8c.html":[2,0,2,1],
-"ahd__bayer_8c.html#a0a10c31feb99742199ca9b8479809ee4":[2,0,2,1,8],
-"ahd__bayer_8c.html#a42d5a3f91ac1e8add4295c0d288c182f":[2,0,2,1,3],
-"ahd__bayer_8c.html#a74e75242132eaabbc1c512488a135926":[2,0,2,1,6],
+"ahd__bayer_8c.html#a0a10c31feb99742199ca9b8479809ee4":[2,0,2,1,7],
+"ahd__bayer_8c.html#a74e75242132eaabbc1c512488a135926":[2,0,2,1,5],
 "ahd__bayer_8c.html#a79d10e672abb49ad63eeaa8aaef57c38":[2,0,2,1,1],
 "ahd__bayer_8c.html#a7e98848076c6c8edd529cd3b04beae8d":[2,0,2,1,0],
-"ahd__bayer_8c.html#a8d23feea868a983c8c2b661e1e16972f":[2,0,2,1,7],
-"ahd__bayer_8c.html#aacc3ee1a7f283f8ef65cea31f4436a95":[2,0,2,1,5],
+"ahd__bayer_8c.html#a8d23feea868a983c8c2b661e1e16972f":[2,0,2,1,6],
+"ahd__bayer_8c.html#aacc3ee1a7f283f8ef65cea31f4436a95":[2,0,2,1,4],
 "ahd__bayer_8c.html#aaefe6f014fd5125ca10cc315080003c7":[2,0,2,1,2],
-"ahd__bayer_8c.html#acfbc006ea433ad708fdee3e82996e721":[2,0,2,1,4],
-"ahd__bayer_8c.html#ad3e98332c40eea761faae753444cfcad":[2,0,2,1,9],
+"ahd__bayer_8c.html#acfbc006ea433ad708fdee3e82996e721":[2,0,2,1,3],
+"ahd__bayer_8c.html#ad3e98332c40eea761faae753444cfcad":[2,0,2,1,8],
 "annotated.html":[1,0],
 "bayer_8c.html":[2,0,2,2],
 "bayer_8c.html#a38afd801f9ae2b9ebcf1924e90b9a28e":[2,0,2,2,6],
@@ -167,50 +166,47 @@ var NAVTREEINDEX0 =
 "gamma_8h_source.html":[2,0,2,7],
 "globals.html":[2,1,0],
 "globals.html":[2,1,0,0],
-"globals_0x62.html":[2,1,0,1],
-"globals_0x63.html":[2,1,0,2],
-"globals_0x64.html":[2,1,0,3],
-"globals_0x66.html":[2,1,0,4],
-"globals_0x67.html":[2,1,0,5],
-"globals_0x68.html":[2,1,0,6],
-"globals_0x70.html":[2,1,0,7],
-"globals_0x73.html":[2,1,0,8],
+"globals_b.html":[2,1,0,1],
+"globals_c.html":[2,1,0,2],
+"globals_d.html":[2,1,0,3],
 "globals_defs.html":[2,1,6],
 "globals_enum.html":[2,1,4],
 "globals_eval.html":[2,1,5],
-"globals_func.html":[2,1,1],
+"globals_f.html":[2,1,0,4],
 "globals_func.html":[2,1,1,0],
-"globals_func_0x64.html":[2,1,1,1],
-"globals_func_0x66.html":[2,1,1,2],
-"globals_func_0x67.html":[2,1,1,3],
-"globals_func_0x70.html":[2,1,1,4],
-"globals_func_0x73.html":[2,1,1,5],
+"globals_func.html":[2,1,1],
+"globals_func_d.html":[2,1,1,1],
+"globals_func_f.html":[2,1,1,2],
+"globals_func_g.html":[2,1,1,3],
+"globals_func_p.html":[2,1,1,4],
+"globals_func_s.html":[2,1,1,5],
+"globals_g.html":[2,1,0,5],
+"globals_h.html":[2,1,0,6],
+"globals_p.html":[2,1,0,7],
+"globals_s.html":[2,1,0,8],
 "globals_type.html":[2,1,3],
 "globals_vars.html":[2,1,2],
 "gphoto2-abilities-list_8c.html":[2,0,2,8],
-"gphoto2-abilities-list_8c.html#a0977e0262d525a380889bd748187f8cd":[2,0,2,8,20],
-"gphoto2-abilities-list_8c.html#a0c449b4f3481ce5a8611b052dbd7f88d":[2,0,2,8,21],
-"gphoto2-abilities-list_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,8,7],
-"gphoto2-abilities-list_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,2,8,8],
-"gphoto2-abilities-list_8c.html#a125df89361f5565ab6b65127be3c92b1":[2,0,2,8,19],
-"gphoto2-abilities-list_8c.html#a1721e090bfed621b3d579616f7af7f7b":[2,0,2,8,22],
-"gphoto2-abilities-list_8c.html#a1f03e4d79424c41ce1950a4c1c006429":[2,0,2,8,23],
-"gphoto2-abilities-list_8c.html#a31f5b59ba0bbc5f65f733ef299e2533d":[2,0,2,8,6],
+"gphoto2-abilities-list_8c.html#a0977e0262d525a380889bd748187f8cd":[2,0,2,8,17],
+"gphoto2-abilities-list_8c.html#a0c449b4f3481ce5a8611b052dbd7f88d":[2,0,2,8,18],
+"gphoto2-abilities-list_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,8,5],
+"gphoto2-abilities-list_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,2,8,6],
+"gphoto2-abilities-list_8c.html#a125df89361f5565ab6b65127be3c92b1":[2,0,2,8,16],
+"gphoto2-abilities-list_8c.html#a1721e090bfed621b3d579616f7af7f7b":[2,0,2,8,19],
+"gphoto2-abilities-list_8c.html#a1f03e4d79424c41ce1950a4c1c006429":[2,0,2,8,20],
 "gphoto2-abilities-list_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,2,8,2],
-"gphoto2-abilities-list_8c.html#a35dba5cce03019017bedb69df7fdd6da":[2,0,2,8,15],
-"gphoto2-abilities-list_8c.html#a42d5a3f91ac1e8add4295c0d288c182f":[2,0,2,8,11],
-"gphoto2-abilities-list_8c.html#a58410b00e92207a02eddc629876b8041":[2,0,2,8,24],
-"gphoto2-abilities-list_8c.html#a5f80e8482ab93869489531a8c7ce7006":[2,0,2,8,13],
-"gphoto2-abilities-list_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,2,8,12],
-"gphoto2-abilities-list_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,2,8,10],
-"gphoto2-abilities-list_8c.html#a8880b2ceed89e39933df14a5a80f8163":[2,0,2,8,16],
+"gphoto2-abilities-list_8c.html#a35dba5cce03019017bedb69df7fdd6da":[2,0,2,8,12],
+"gphoto2-abilities-list_8c.html#a58410b00e92207a02eddc629876b8041":[2,0,2,8,21],
+"gphoto2-abilities-list_8c.html#a5f80e8482ab93869489531a8c7ce7006":[2,0,2,8,10],
+"gphoto2-abilities-list_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,2,8,9],
+"gphoto2-abilities-list_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,2,8,8],
+"gphoto2-abilities-list_8c.html#a8880b2ceed89e39933df14a5a80f8163":[2,0,2,8,13],
 "gphoto2-abilities-list_8c.html#aaac97ee546bbc766abdad2c3620573be":[2,0,2,8,3],
-"gphoto2-abilities-list_8c.html#ab1002450d0de551738c40dc4e1b002ec":[2,0,2,8,18],
-"gphoto2-abilities-list_8c.html#abda07b4f6b0000a5d5f359e6920492e5":[2,0,2,8,17],
-"gphoto2-abilities-list_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,2,8,9],
+"gphoto2-abilities-list_8c.html#ab1002450d0de551738c40dc4e1b002ec":[2,0,2,8,15],
+"gphoto2-abilities-list_8c.html#abda07b4f6b0000a5d5f359e6920492e5":[2,0,2,8,14],
+"gphoto2-abilities-list_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,2,8,7],
 "gphoto2-abilities-list_8c.html#add6dfc1077058ff26d79cdb18099d58a":[2,0,2,8,4],
-"gphoto2-abilities-list_8c.html#aee30e543062b8f2ca10f5c1eb64c9b8d":[2,0,2,8,14],
-"gphoto2-abilities-list_8c.html#aefa85642ca98f16c304f90dd7c760c6b":[2,0,2,8,5],
+"gphoto2-abilities-list_8c.html#aee30e543062b8f2ca10f5c1eb64c9b8d":[2,0,2,8,11],
 "gphoto2-abilities-list_8h.html":[2,0,1,0],
 "gphoto2-abilities-list_8h.html#a0977e0262d525a380889bd748187f8cd":[2,0,1,0,13],
 "gphoto2-abilities-list_8h.html#a0c449b4f3481ce5a8611b052dbd7f88d":[2,0,1,0,14],
@@ -249,5 +245,9 @@ var NAVTREEINDEX0 =
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2fa66f652e8f43eeb5b4c61e885caa43a65":[2,0,1,0,2,1],
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2fa6e1e8db16a18e608337310ac34be3c6f":[2,0,1,0,2,2],
 "gphoto2-abilities-list_8h.html#adb4109f5f068c42b37b1a6506b60de2fad07f0804935441b382b2094b1eb2a227":[2,0,1,0,2,3],
-"gphoto2-abilities-list_8h.html#aee30e543062b8f2ca10f5c1eb64c9b8d":[2,0,1,0,7]
+"gphoto2-abilities-list_8h.html#aee30e543062b8f2ca10f5c1eb64c9b8d":[2,0,1,0,7],
+"gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126e":[2,0,1,0,6],
+"gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126ea3011adb79ee494e5d9b2329641af8f6c":[2,0,1,0,6,1],
+"gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126ea994862eaf8128a5b062b909b82112e0f":[2,0,1,0,6,0],
+"gphoto2-abilities-list_8h_source.html":[2,0,1,0]
 };
