@@ -1,55 +1,41 @@
 var NAVTREEINDEX3 =
 {
-"gphoto2-port-info-list_8h.html#a4621674c74440cc4d68d24e45fc9f148":[2,0,3,0,0,18],
-"gphoto2-port-info-list_8h.html#a541be7394f5ab48304fe48e5a6cec757":[2,0,3,0,0,0],
-"gphoto2-port-info-list_8h.html#a61b08d6eddea3c0e0c51869363632cea":[2,0,3,0,0,11],
-"gphoto2-port-info-list_8h.html#a625daffc59c3fd87b9f3b73b129f3b96":[2,0,3,0,0,3],
-"gphoto2-port-info-list_8h.html#a70f65ef80a59174adfa52c3e199752d4":[2,0,3,0,0,6],
-"gphoto2-port-info-list_8h.html#a85b97ad361854a8076b61be70fe85304":[2,0,3,0,0,10],
-"gphoto2-port-info-list_8h.html#a8677c876b22dc6b4545e92fda9810ed4":[2,0,3,0,0,15],
-"gphoto2-port-info-list_8h.html#a9736997967ed0bdb2ac0ace4e02df531":[2,0,3,0,0,5],
-"gphoto2-port-info-list_8h.html#a9810bfba9c986f4d102cfaf649199f21":[2,0,3,0,0,4],
-"gphoto2-port-info-list_8h.html#ab60c983825bfa2b6aa2fcb1e1a32b08f":[2,0,3,0,0,9],
-"gphoto2-port-info-list_8h.html#abd6e63f271c916e041be85e7b279374a":[2,0,3,0,0,1],
-"gphoto2-port-info-list_8h.html#acbb59be40d7a67a13b7ffd26dcd3e9bb":[2,0,3,0,0,7],
-"gphoto2-port-info-list_8h.html#ad925c660b558db82d22c62e8ae09c756":[2,0,3,0,0,13],
-"gphoto2-port-info-list_8h.html#ae2595948920409d2002d879475d6e350":[2,0,3,0,0,20],
 "gphoto2-port-info-list_8h.html#af1f1553e664584f74724a8825829bc09":[2,0,3,0,0,16],
 "gphoto2-port-info-list_8h_source.html":[2,0,3,0,0],
 "gphoto2-port-info_8h.html":[2,0,3,1,1],
 "gphoto2-port-info_8h_source.html":[2,0,3,1,1],
 "gphoto2-port-library_8h.html":[2,0,3,0,1],
 "gphoto2-port-library_8h.html#a1691b9d2ab5502d0dabec4445ebf2bef":[2,0,3,0,1,5],
-"gphoto2-port-library_8h.html#a19aa819c6285524241e2ba19ec046f65":[2,0,3,0,1,2],
-"gphoto2-port-library_8h.html#a32b12bec48bb0407606b4af34409808c":[2,0,3,0,1,1],
+"gphoto2-port-library_8h.html#a548bbb8e99c1aa3a4a8ca2ccd6b3b15f":[2,0,3,0,1,2],
 "gphoto2-port-library_8h.html#a677295b647d8d00d3cdb4caa14e36aae":[2,0,3,0,1,4],
-"gphoto2-port-library_8h.html#a85c390fae0fd26f2025a9a97f6862691":[2,0,3,0,1,3],
 "gphoto2-port-library_8h.html#a9e13d12e5c9833e6600b5c05c7e9bea7":[2,0,3,0,1,7],
+"gphoto2-port-library_8h.html#aa9e5f9918113e292954e61d4183bf98b":[2,0,3,0,1,3],
 "gphoto2-port-library_8h.html#af4a2e56a43c90ed9d4766c9ba6919cc1":[2,0,3,0,1,6],
+"gphoto2-port-library_8h.html#af9381a47a6db50ab2f3511d0aa35cbe1":[2,0,3,0,1,1],
 "gphoto2-port-library_8h_source.html":[2,0,3,0,1],
 "gphoto2-port-log_8c.html":[2,0,3,1,2],
 "gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,1,2,16],
-"gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,1,2,15],
-"gphoto2-port-log_8c.html#a1f87fb4d74a1713ca959ebee544ba860":[2,0,3,1,2,14],
+"gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,1,2,14],
 "gphoto2-port-log_8c.html#a25d3dff9fc4f2a43d2fb7c992d46e24b":[2,0,3,1,2,4],
 "gphoto2-port-log_8c.html#a2bdf0f15991734c7a632c10714553277":[2,0,3,1,2,5],
 "gphoto2-port-log_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,3,1,2,1],
-"gphoto2-port-log_8c.html#a3b5dcab5cde5c5c3e39255d892765fc1":[2,0,3,1,2,11],
 "gphoto2-port-log_8c.html#a425183fc022968cf26219b38421b42ee":[2,0,3,1,2,9],
 "gphoto2-port-log_8c.html#a4d62d7864045598068173b20f87380ea":[2,0,3,1,2,6],
+"gphoto2-port-log_8c.html#a5e9bad704f3b065a2d5b653c7516a1ee":[2,0,3,1,2,17],
 "gphoto2-port-log_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,2,10],
-"gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,1,2,12],
+"gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,1,2,11],
 "gphoto2-port-log_8c.html#aa670fefafc10fc80dba398d2050ce62c":[2,0,3,1,2,3],
-"gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,1,2,13],
+"gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,1,2,12],
+"gphoto2-port-log_8c.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,1,2,15],
+"gphoto2-port-log_8c.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,1,2,13],
 "gphoto2-port-log_8c.html#accc780c98fc95b8ddce8f259c1575745":[2,0,3,1,2,7],
 "gphoto2-port-log_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,3,1,2,2],
 "gphoto2-port-log_8c.html#ae21578f6dac5be34d83475a83e271d73":[2,0,3,1,2,8],
 "gphoto2-port-log_8h.html":[2,0,3,0,2],
-"gphoto2-port-log_8h.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,0,2,7],
+"gphoto2-port-log_8h.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,0,2,8],
 "gphoto2-port-log_8h.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,0,2,6],
-"gphoto2-port-log_8h.html#a1f87fb4d74a1713ca959ebee544ba860":[2,0,3,0,2,5],
+"gphoto2-port-log_8h.html#a4ca34ac78083b2afae39d798cb32353b":[2,0,3,0,2,1],
 "gphoto2-port-log_8h.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,0,2,3],
-"gphoto2-port-log_8h.html#a94751f687dece0c1c7a145287c1b5581":[2,0,3,0,2,1],
 "gphoto2-port-log_8h.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,0,2,4],
 "gphoto2-port-log_8h.html#ab9d873393f29f25bb32cb8fea18e0024":[2,0,3,0,2,0],
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06b":[2,0,3,0,2,2],
@@ -57,6 +43,8 @@ var NAVTREEINDEX3 =
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06ba1fbaa945332b1e324217c2a4e27015dd":[2,0,3,0,2,2,0],
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06bab7502e71c4972bf803722a33b99be75f":[2,0,3,0,2,2,3],
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06badfd0d1ea537692a3dd8acc3b5675c9d2":[2,0,3,0,2,2,2],
+"gphoto2-port-log_8h.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,0,2,7],
+"gphoto2-port-log_8h.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,0,2,5],
 "gphoto2-port-log_8h_source.html":[2,0,3,0,2],
 "gphoto2-port-portability_8c.html":[2,0,3,1,3],
 "gphoto2-port-portability_8c.html#a523999a1e3fa0730e1d8b42d25dab59a":[2,0,3,1,3,3],
@@ -105,18 +93,18 @@ var NAVTREEINDEX3 =
 "gphoto2-port-version_8c.html":[2,0,3,1,5],
 "gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,1,5,0],
 "gphoto2-port-version_8h.html":[2,0,3,0,5],
-"gphoto2-port-version_8h.html#a0754aa7ffa6398d89949a1681bf5d668":[2,0,3,0,5,0],
 "gphoto2-port-version_8h.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,0,5,2],
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719":[2,0,3,0,5,1],
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719a4e1b3c861cc4c757d294f356eaf69c82":[2,0,3,0,5,1,1],
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719a6138e6df0cd17c5cb782279d11b4bc1c":[2,0,3,0,5,1,0],
+"gphoto2-port-version_8h.html#a93ba51fe96ba3f71062d8a814fa70d52":[2,0,3,0,5,0],
 "gphoto2-port-version_8h_source.html":[2,0,3,0,5],
 "gphoto2-port_8c.html":[2,0,3,1,6],
 "gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277":[2,0,3,1,6,10],
 "gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897":[2,0,3,1,6,45],
 "gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2":[2,0,3,1,6,39],
 "gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44":[2,0,3,1,6,23],
-"gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,3,1,6,5],
+"gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,3,1,6,4],
 "gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d":[2,0,3,1,6,44],
 "gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca":[2,0,3,1,6,47],
 "gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a":[2,0,3,1,6,16],
@@ -136,8 +124,9 @@ var NAVTREEINDEX3 =
 "gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62":[2,0,3,1,6,17],
 "gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48":[2,0,3,1,6,37],
 "gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5":[2,0,3,1,6,20],
-"gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a":[2,0,3,1,6,6],
+"gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a":[2,0,3,1,6,5],
 "gphoto2-port_8c.html#a7dd9e079511891ec9996ebb25c0e6814":[2,0,3,1,6,3],
+"gphoto2-port_8c.html#a828c4f99cd2fcdbf9b83793b1c7e7ccb":[2,0,3,1,6,7],
 "gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d":[2,0,3,1,6,22],
 "gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29":[2,0,3,1,6,32],
 "gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4":[2,0,3,1,6,41],
@@ -145,12 +134,11 @@ var NAVTREEINDEX3 =
 "gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957":[2,0,3,1,6,21],
 "gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb":[2,0,3,1,6,27],
 "gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e":[2,0,3,1,6,51],
-"gphoto2-port_8c.html#a9abb452b72afcd88b55ba65065feff20":[2,0,3,1,6,4],
 "gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828":[2,0,3,1,6,15],
 "gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c":[2,0,3,1,6,11],
 "gphoto2-port_8c.html#aa5c3be2ad2546c829dc21d4d8fabb08d":[2,0,3,1,6,25],
 "gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54":[2,0,3,1,6,50],
-"gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525":[2,0,3,1,6,7],
+"gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525":[2,0,3,1,6,6],
 "gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0":[2,0,3,1,6,18],
 "gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5":[2,0,3,1,6,14],
 "gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e":[2,0,3,1,6,12],
@@ -249,5 +237,17 @@ var NAVTREEINDEX3 =
 "gphoto2-result_8h.html#a824a44c818defda66b58058cff4fe098":[2,0,1,7,4],
 "gphoto2-result_8h.html#aa2ccbde81e188dc5f718a5f219118ff3":[2,0,1,7,8],
 "gphoto2-result_8h.html#adcbc9d96b811ff4bbcaa56a15c3776bb":[2,0,1,7,1],
-"gphoto2-result_8h.html#ade2d19223246e133a72869939d103a98":[2,0,1,7,3]
+"gphoto2-result_8h.html#ade2d19223246e133a72869939d103a98":[2,0,1,7,3],
+"gphoto2-result_8h.html#aeedb403d0eb07560182191c551dc5178":[2,0,1,7,12],
+"gphoto2-result_8h_source.html":[2,0,1,7],
+"gphoto2-setting_8c.html":[2,0,2,17],
+"gphoto2-setting_8c.html#a4b50249c04f6a48156bad839827e67b7":[2,0,2,17,3],
+"gphoto2-setting_8c.html#a6100f1cf5f3e90c2491807b6db1796af":[2,0,2,17,4],
+"gphoto2-setting_8c.html#a7f8c30ecb636e41b160ace9b51501caa":[2,0,2,17,2],
+"gphoto2-setting_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,2,17,1],
+"gphoto2-setting_8h.html":[2,0,1,8],
+"gphoto2-setting_8h.html#a4b50249c04f6a48156bad839827e67b7":[2,0,1,8,0],
+"gphoto2-setting_8h.html#a6100f1cf5f3e90c2491807b6db1796af":[2,0,1,8,1],
+"gphoto2-setting_8h_source.html":[2,0,1,8],
+"gphoto2-version_8c.html":[2,0,2,18]
 };
